// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections.Generic;
using System.Text;

using DotCommunities.Framework.Enums;
using DotCommunities.Framework.Interfaces;
using DotCommunities.Framework.Components;

namespace DotCommunities.Editors
{
    /// <summary>
    /// Control that configures the <see cref="TinyMCE"/> for use as
    /// a community control.
    /// </summary>
    public class CommunityTinyMCE : TinyMCE, ITextEditor
    {
        private AllowHtml allowHtml;
        private TinyMCEConfig config;

        /// <summary>
        /// Configures the <see cref="TinyMCE"/> on loading the control.
        /// </summary>
        /// <param name="e">The <see cref="EventArgs"/> for this event.</param>
        protected override void OnLoad(EventArgs e)
        {
            // Call the base method first
            base.OnLoad(e);

            // Check that we are not posting back
            if (!Page.IsPostBack)
            {
                JavascriptLocation = string.Format("{0}Communities/Common/Editors/TinyMCE/tiny_mce.js", CommunityContext.ApplicationPath);

                config = GetConfig();

                if (AllowHtml == AllowHtml.Full)
                    config.SetStringParam(TinyMCEConfig.StringParameter.theme, "advanced");
                else
                    config.SetStringParam(TinyMCEConfig.StringParameter.theme, "simple");

                config.SetBoolParam(TinyMCEConfig.BoolParameter.add_form_submit_trigger, false);
                config.SetBoolParam(TinyMCEConfig.BoolParameter.focus_alert, true);
            }
        }

        /// <summary>
        /// Gets or sets the <see cref="AllowHtml"/> toolbar options.
        /// </summary>
        public AllowHtml AllowHtml
        {
            get { return allowHtml; }
            set { allowHtml = value; }
        }
    }
}
