// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Collections;

namespace DotCommunities.Editors
{
	/// <summary>
	/// An abstract webcontrol for the TinyMCE editor.
	/// </summary>
	public abstract class TinyMCE : TextBox
	{
		private string _javascriptLocation;
		
		private TinyMCEConfig _config = new TinyMCEConfig();
		
		/// <summary>
        /// Path to the <see cref="TinyMCE"/> javascript file.
		/// </summary>
		public string JavascriptLocation
		{
			get { return this._javascriptLocation; }
			set { this._javascriptLocation = value; }
		}
		
        /// <summary>
        /// Gets the configuration of the <see cref="TinyMCE"/> control.
        /// </summary>
        /// <returns>A <see cref="TinyMCEConfig"/> oject containing configuration data.</returns>
		public TinyMCEConfig GetConfig()
		{
			return this._config;
		}

        /// <summary>
        /// Loads the <see cref="TinyMCE"/> control.
        /// </summary>
        /// <param name="e">The loading event arguments.</param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            if (this.Height != Unit.Empty)
            {
                base.Style["height"] = this.Height.ToString();
                this.Height = Unit.Empty;
            }
            else
                base.Style["height"] = "360px;";

            if (this.Width != Unit.Empty)
            {
                base.Style["width"] = this.Width.ToString();
                this.Width = Unit.Empty;
            }
            else
                base.Style["width"] = "100%";

            this.TextMode = TextBoxMode.MultiLine;
        }
		
        /// <summary>
        /// Draws the <see cref="TinyMCE"/> editor.
        /// </summary>
        /// <param name="writer">The writer to draw the editor to.</param>
        protected override void Render(HtmlTextWriter writer)
        {
            base.Render(writer);

            Type type = typeof(string);

            if (!this.Page.ClientScript.IsClientScriptBlockRegistered(type, base.GetType().FullName))
            {
                this.Page.ClientScript.RegisterClientScriptBlock(type, base.GetType().FullName, "");
                writer.Write("<script language=\"javascript\" type=\"text/javascript\" src=\"{0}\"></script>", this.Page.Response.ApplyAppPathModifier(JavascriptLocation));
            }

            if (!this.Page.ClientScript.IsClientScriptBlockRegistered(type, this.ClientID))
            {
                this.Page.ClientScript.RegisterStartupScript(type, this.ClientID, "");
                writer.Write("<!-- tinyMCE -->\n");
                writer.Write("<script language=\"javascript\" type=\"text/javascript\">tinyMCE.init( ");

                this._config.SetStringParam(TinyMCEConfig.StringParameter.mode, "exact");
                this._config.SetStringParam(TinyMCEConfig.StringParameter.elements, this.ClientID.ToString());

                this._config.Write(writer);

                writer.Write(");</script>\n");
                writer.Write("<!-- /tinyMCE -->\n");
            }
        }
	}
}