// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections;
using System.Web.UI;

namespace DotCommunities.Editors
{
	/// <summary>
	/// Configuration class for the TinyMCE editor control.
	/// </summary>
	public class TinyMCEConfig
	{
		private Hashtable _parameters = new Hashtable();
		
		/// <summary>
		/// Retreives a configuration parameter
		/// </summary>
		/// <param name="parameter">One of the predefined conf parameters</param>
		/// <returns>The parameter value if set or null if no value has been set for this parameter</returns>
		public string GetStringParam(StringParameter parameter)
		{
			string val = (string) this._parameters[Enum.GetName(typeof(StringParameter), parameter)];
			
			if (val == null || val == string.Empty)
				return val;
			else if (val.StartsWith("'") && val.EndsWith("'"))
			{			
				// Remove first and last char
				val = val.Substring(0, val.Length-1);
				val = val.Substring(1, val.Length-1);

				return val;					
			}
			
			return (string) this._parameters[Enum.GetName(typeof(StringParameter), parameter)];
		}
		
		/// Retreives a configuration parameter
		/// </summary>
		/// <param name="parameter">One of the predefined conf parameters</param>
		/// <returns>The parameter value if set or null if no value has been set for this parameter</returns>
		public bool GetBoolParam(BoolParameter parameter)
		{
			string val = (string) this._parameters[Enum.GetName(typeof(BoolParameter), parameter)];
			
			return (val != null && val.Equals("true"));
		}
		
		/// <summary>
		/// Sets a configuration parameter
		/// </summary>
		/// <param name="parameter">One of the predefined conf parameters</param>
		/// <param name="value">The parameter value</param>
		public void SetStringParam(StringParameter parameter, string value)
		{
			try 
            {
				// Remove any previous value
				this._parameters.Remove(Enum.GetName(typeof(StringParameter), parameter));
			}
			catch (Exception) 
            {
				// ignore
			}
			
			this._parameters.Add(Enum.GetName(typeof(StringParameter), parameter), "'" + value + "'");
		}
		
		/// <summary>
		/// Sets a configuration parameter
		/// </summary>
		/// <param name="parameter">One of the predefined conf parameters</param>
		/// <param name="value">The parameter value</param>
		public void SetBoolParam(BoolParameter parameter, bool value)
		{
			try 
            {
				// Remove any previous value
				this._parameters.Remove(Enum.GetName(typeof(BoolParameter), parameter));
			}
			catch (Exception) 
            {
				// ignore
			}
			
			this._parameters.Add(Enum.GetName(typeof(BoolParameter), parameter), value.ToString().ToLower());
		}
		
		internal void Write(HtmlTextWriter outWriter)
		{				
			
			outWriter.Write("{");

			IDictionaryEnumerator e = this._parameters.GetEnumerator();
			
			bool first = true;
			
			while (e.MoveNext()) 
			{
				if (!first)
					outWriter.Write(",");
				else
					first = false;
					
				outWriter.Write(e.Key.ToString() + ":" + e.Value.ToString());
			}			
			
			outWriter.Write("}");			
		}			
		
		/// <summary>
		/// The config values in version 1.36 of the tinyMCE javascript that hols string values
		/// </summary>
		public enum StringParameter
		{
			mode,
			theme,
			language,
			docs_language,
			elements,
			textarea_trigger,
			valid_elements,
			extended_valid_elements,
			invalid_elements,
			encoding,
			urlconvertor_callback,
			save_callback,
			document_base_url,
			visual_table_style,
			setupcontent_callback,
			custom_undo_redo_levels,
			directionality
		};			 			
		
		/// <summary>
		/// The config values in version 1.36 of the tinyMCE javascript that holds bool values
		/// </summary>
		public enum BoolParameter
		{		
			plugins,
			debug,
			force_br_newlines,
			add_form_submit_trigger,
			relative_urls,
			remove_script_host,
			focus_alert,
			visual,
			fix_content_duplication,
			custom_undo_redo,
			verify_css_classes,
			trim_span_elements,
			verify_html,
			apply_source_formatting,
			auto_cleanup_word,
			cleanup_on_startup,
			inline_styles
		}
	}
}
