// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;

namespace DotCommunities.Framework
{
    /// <summary>
    /// Represents a category that can be associated with .communities content.
    /// </summary>
    [Serializable]
    public class Category
    {
        private int categoryID;
        private int sectionID;

        private string sectionName;
        private string name;
        private string imagePath;
        private string description;

        #region Public Properties
        /// <summary>
        /// Gets or sets the ID for the category.
        /// </summary>
        public int CategoryID
        {
            get { return categoryID; }
            set { categoryID = value; }
        }

        /// <summary>
        /// Gets or sets the ID for the section.
        /// </summary>
        public int SectionID
        {
            get { return sectionID; }
            set { sectionID = value; }
        }

        /// <summary>
        /// Gets the section name for the category.
        /// </summary>
        public string SectionName
        {
            get { return sectionName; }
        }

        /// <summary>
        /// Gets or sets the name for the category.
        /// </summary>
        public string Name
        {
            get { return name; }
            set { name = value; }
        }

        /// <summary>
        /// Gets or sets the image for the category.
        /// </summary>
        public string ImagePath
        {
            get { return imagePath; }
            set { imagePath = value; }
        }

        /// <summary>
        /// Gets or sets the description for the category.
        /// </summary>
        public string Description
        {
            get { return description; }
            set { description = value; }
        }
        #endregion

        /// <summary>
        /// Creates a new instance of the <see cref="Category"/> object.
        /// </summary>
        /// <param name="dr">An <see cref="IDataReader"/> containing category data.</param>
        public Category(IDataReader dr)
        {
            categoryID = (int)dr["Category_ID"];
            sectionID = (int)dr["Section_ID"];
            sectionName = dr["Section_name"].ToString();
            imagePath = dr["Category_Image"].ToString();
            name = dr["Category_Name"].ToString();
            description = dr["Category_Description"].ToString();
        }
    }
}
