// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections.Generic;
using System.Text;

namespace DotCommunities.Framework.Collections
{
    /// <summary>
    /// This class represents a collection of comments.
    /// </summary>
    public class CommentCollection : List<object>
    {
        Dictionary<int, Comment> commentCollection;

        /// <summary>
        /// Initializes a new instance of the <see cref="CommentCollection"/> class. 
        /// </summary>
        public CommentCollection() 
            : base() 
        {
            commentCollection = new Dictionary<int, Comment>();
        }

        /// <summary>
        /// Updates a comment to the List and internal Dictionary. 
        /// </summary>
        /// <param name="index">The index of the item to add.</param>
        /// <returns>The <see cref="Comment"/> object at the selected index.</returns>
        public new object this[int index]
        {
            set
            {
                commentCollection[(value as Comment).ContentPageID] = (Comment)value;
                base[index] = value;
            }
            get { return base[index]; }
        }

        /// <summary>
        /// Adds a new comment to the List and internal Dictionary.
        /// </summary>
        /// <param name="value">The <see cref="Comment"/> object to add.</param>
        /// <returns>The current index of the <see cref="Comment"/>.</returns>
        public new void Add(object value)
        {
            commentCollection[(value as Comment).ContentPageID] = (Comment)value;
            base.Add(value);
        }

        /// <summary>
        /// Gets all the immediate child comments by iterating through the List. 
        /// </summary>
        /// <param name="replyID">The parent ID of the comments to return.</param>
        /// <returns>A <see cref="CommentCollection"/> containing child comments.</returns>
        public CommentCollection GetChildren(int replyID)
        {
            CommentCollection colChildren = new CommentCollection();

            foreach (Comment c in this)
                if (c.ReplyID == replyID)
                    colChildren.Add(c);

            return colChildren;
        }

        /// <summary>
        /// Gets the nesting level of a comment. 
        /// </summary>
        /// <param name="comment">The <see cref="Comment"/> object to find.</param>
        /// <returns>The nesing level (up to 50).</returns>
        public int GetReplyLevel(Comment comment)
        {
            int level = -1;

            while (comment != null)
            {
                level++;
                comment = commentCollection[comment.ReplyID];

                if (level > 50)
                    break;
            }
            return level;
        }
    }
}
