// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections.Generic;
using System.Text;

namespace DotCommunities.Framework.Collections
{
    /// <summary>
    /// Represents a collection of <see cref="GenericHandler"/> objects containing page data.
    /// </summary>
    public class GenericHandlerCollection : Dictionary<string, GenericHandler>
    {
        private List<string> extensionNames;

        /// <summary>
        /// The list of all the exstension names that generic handlers
        /// are registered for.
        /// </summary>
        public List<string> ExtensionNames
        {
            get { return extensionNames; }
        }

        /// <summary>
        /// Create a new collection ignoring the case.
        /// </summary>
        public GenericHandlerCollection()
            : base(StringComparer.OrdinalIgnoreCase) 
        {
            extensionNames = new List<string>();
        }

        /// <summary>
        /// Adds a <see cref="GenericHandler"/> to the collection.
        /// </summary>
        /// <param name="key">The handler name.</param>
        /// <param name="value">The <see cref="GenericHandler"/> to add.</param>
        public new void Add(string key, GenericHandler value)
        {
            // Don't allow duplicate values
            if (ContainsKey(key))
                return;

            // Add the extension types
            foreach (string s in value.ExtensionNames)
                extensionNames.Add(s);

            // Perform the add operation
            base.Add(key, value);
        }
    }
}
