// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;

namespace DotCommunities.Framework
{
    /// <summary>
    /// Represents all the information about a particular comment.
    /// </summary>
    [Serializable]
    public class Comment : CommunityContent
    {
        int _replyID;
        int _parentID;
        string _text;

        /// <summary>
        /// Gets or sets the immediate parent of the comment.
        /// </summary>
        /// <value>The reply ID.</value>
        public int ReplyID
        {
            get { return _replyID; }
            set { _replyID = value; }
        }

        /// <summary>
        /// Gets or sets the parent ID.
        /// </summary>
        /// <value>The parent ID.</value>
        public int ParentID
        {
            get { return _parentID; }
            set { _parentID = value; }
        }

        /// <summary>
        /// Gets or sets the body text of the comment.
        /// </summary>
        /// <value>The text.</value>
        public string Text
        {
            get { return _text; }
            set { _text = value; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Comment"/> class.
        /// </summary>
        /// <param name="dr">An <see cref="IDataReader"/> containing the comment data.</param>
        public Comment(IDataReader dr)
            : base(dr)
        {
            _text = (string)dr["Comment_Text"];
            _parentID = (int)dr["ContentPage_ParentID"];

            if (dr["ContentPage_ReplyID"] != DBNull.Value)
                _replyID = (int)dr["ContentPage_ReplyID"];
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Comment"/> class.
        /// </summary>
        /// <param name="dr">A <see cref="DataRow"/> containing the comment data.</param>
        public Comment(DataRow dr)
            : base(dr)
        {
            _text = (string)dr["Comment_Text"];
            _parentID = (int)dr["ContentPage_ParentID"];

            if (dr["ContentPage_ReplyID"] != DBNull.Value)
                _replyID = (int)dr["ContentPage_ReplyID"];
        }
    }
}
