// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.Compilation;

using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Properties;
using DotCommunities.Framework.Enums;

namespace DotCommunities.Framework.Components
{
    public class CommunityPageHandlerFactory : IHttpHandlerFactory
    {
        /// <summary>
        /// Returns the correct instance of an aspx page.
        /// </summary>
        /// <param name="context">The current context.</param>
        /// <param name="url">The virtual url for the page.</param>
        /// <returns>A <see cref="IHttpHandler"/> for the requested page.</returns>
        private IHttpHandler ProcessVirtualPage(HttpContext context, string url)
        {
            // If we have the page information we can go ahead and 
            // rewrite the path to the default page
            if (CommunityContext.CurrentPage != null)
                return PageParser.GetCompiledPageInstance(url,
                   context.Server.MapPath(CommunityContext.CommunityBasePage), context);

            // Here we just map the request to the physical page
            return PageParser.GetCompiledPageInstance(url,
               context.Server.MapPath(url), context);
        }

        #region IHttpHandlerFactory Members

        /// <summary>
        /// Retrieves the correct instance of the current page.
        /// </summary>
        /// <param name="context">The current context.</param>
        /// <param name="requestType">The request type.</param>
        /// <param name="url">The page url.</param>
        /// <param name="pathTranslated">The translated path.</param>
        /// <returns>A <see cref="IHttpHandler"/> for the requested page.</returns>
        public IHttpHandler GetHandler(HttpContext context, string requestType, string url, string pathTranslated)
        {
            // Redirect to the offline page
            if ((!CommunityContext.IsAdministrationPath) && CommunityContext.CommunityStatus == CommunityStatus.Offline)
            {
                context.Response.Redirect(CommunityContext.CommunityOfflinePage, false);
                return null;
            }

            // Return the correct page handler
            if (!CommunityContext.IsHandlersPath)
                return ProcessVirtualPage(context, url);

            // Do not return any pages from the handlers path
            context.Response.Redirect(CommunityContext.CommunityDefaultPage, false);
            return null;
        }

        /// <summary>
        /// Releases the handler.
        /// </summary>
        /// <param name="handler">The handler instance.</param>
        public void ReleaseHandler(IHttpHandler handler)
        {
            // Do nothing here
        }

        #endregion
    }
}
