// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.Profile;

using DotCommunities.Framework.Managers;

namespace DotCommunities.Framework.Components
{
    /// <summary>
    /// The base class for all profiles used by .communities.
    /// </summary>
    /// <remarks>
    /// These profile proerties are required for .communities to work properly.
    /// Use this as the base class for all extended profiles.
    /// </remarks>
    public class CommunityProfileBase : ProfileBase
    {
        /// <summary>
        /// Represents the current view style for comments. Allows
        /// for anonymous users to use the value too.
        /// </summary>
        [SettingsAllowAnonymous(true)]
        public int CommentView
        {
            get
            {
                try
                {
                    return (int)base["CommentView"];
                }
                catch
                {
                    return 0;
                }
            }
            set { base["CommentView"] = value; }
        }

        /// <summary>
        /// Represents the current view size of grid page size controls.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public int DefaultGridPageSize
        {
            get
            {
                try
                {
                    return (int)base["DefaultGridPageSize"];
                }
                catch
                {
                    return 0;
                }
            }
            set { base["DefaultGridPageSize"] = value; }
        }

        /// <summary>
        /// Represents the users time zone offset.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public string TimeZone
        {
            get { return base["TimeZone"].ToString(); }
            set { base["TimeZone"] = value; }
        }

        /// <summary>
        /// Represents the users selected text editor. Allows for 
        /// anonymous users to use the value too.
        /// </summary>
        [SettingsAllowAnonymous(true)]
        public string TextEditor
        {
            get { return base["TextEditor"].ToString(); }
            set { base["TextEditor"] = value; }
        }

        /// <summary>
        /// Permits other users to contact this user via private
        /// messaging.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public bool PrivateMessages
        {
            get
            {
                try
                {
                    return (bool)base["PrivateMessages"];
                }
                catch
                {
                    return false;
                }
            }
            set { base["PrivateMessages"] = value; }
        }

        /// <summary>
        /// The users first name.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public string FirstName
        {
            get { return base["FirstName"].ToString(); }
            set { base["FirstName"] = value; }
        }

        /// <summary>
        /// The users last name.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public string LastName
        {
            get { return base["LastName"].ToString(); }
            set { base["LastName"] = value; }
        }

        /// <summary>
        /// The users publically viewed e-mail address.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public string PublicEMail
        {
            get { return base["PublicEMail"].ToString(); }
            set { base["PublicEMail"] = value; }
        }

        /// <summary>
        /// Permits publishing of the public e-mail address in an
        /// RSS feed.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public bool PublishEMail
        {
            get
            {
                try
                {
                    return (bool)base["PublishEMail"];
                }
                catch
                {
                    return false;
                }
            }
            set { base["PublishEMail"] = value; }
        }

        /// <summary>
        /// Permits publishing of the users full name in an
        /// RSS feed.
        /// </summary>
        [SettingsAllowAnonymous(false)]
        public bool PublishFullName
        {
            get
            {
                try
                {
                    return (bool)base["PublishFullName"];
                }
                catch
                {
                    return false;
                }
            }
            set { base["PublishFullName"] = value; }
        }
    }
}
