// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.IO;
using System.Text;
using System.Xml;
using System.Xml.Serialization;

using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Enums;

namespace DotCommunities.Framework.Components
{
    /// <summary>
    /// When inherited in a class, adds the ability for the object to be serialised
    /// to an XML string and back.
    /// </summary>
    [Serializable]
    public abstract class SerializableObject
    {
        /// <summary>
        /// Serialises the object into an XML string.
        /// </summary>
        /// <returns>The XML string containing the object properties.</returns>
        public string ToXmlString()
        {
            StringBuilder sb = new StringBuilder();
            StringWriter writer = new StringWriter(sb);
            XmlSerializer serializer = new XmlSerializer(this.GetType());

            try
            {
                serializer.Serialize(writer, this);                
            }
            catch (InvalidOperationException e)
            {
                // Log the error
                LogManager.LogException(EventCode.Framework, LogManager.LogCategory.Exceptions, e);
            }

            return writer.GetStringBuilder().ToString();
        }

        /// <summary>
        /// Deserialises the object from the XML.
        /// </summary>
        /// <param name="xml">The XML string containing the object properties.</param>
        /// <param name="t">The object type.</param>
        /// <returns>The object of type <paramref name="t"/> from the XML string.</returns>
        public static object ToObject(string xml, Type t)
        {
            StringReader sr = new StringReader(xml);
            XmlSerializer xs = new XmlSerializer(t);

            try
            {
                return xs.Deserialize(sr);
            }
            catch (InvalidOperationException e)
            {
                // Log the error
                LogManager.LogException(EventCode.Framework, LogManager.LogCategory.Exceptions, e);
            }

            return null;
        }
    }
}
