// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Text;
using System.Web;
using System.Web.Caching;

using DotCommunities.Framework.Managers;

namespace DotCommunities.Framework.Components
{
    /// <summary>
    /// Absract base sydication handller used to handle and process feeds
    /// such as an RSS feed.
    /// </summary>
    public abstract class SyndicationHandlerBase : CommunityManagerBase, IHttpHandler
    {
        /// <summary>
        /// The current feed xml string.
        /// </summary>
        protected String FeedXml = null;

        /// <summary>
        /// The length of time the feed should be cached.
        /// </summary>
        protected abstract int CacheTime { get; }

        /// <summary>
        /// The key used to lookup the feed uniquely in the cache.
        /// </summary>
        protected abstract string CacheKey { get; }

        /// <summary>
        /// Builds the actual feed.
        /// </summary>
        protected abstract string BuildFeed();

        /// <summary>
        /// Retreives the xml feed from the cache or creates one.
        /// </summary>
        private void ProcessFeed()
        {
            // First we try to get the feed from the cache
            object o = GetCachedItem(CacheKey);

            // If there is no cached feed then we attempt to build it
            if (o == null)
            {
                FeedXml = BuildFeed();

                // If the feed has been built then add it to the cache
                if (!string.IsNullOrEmpty(FeedXml))
                    AddCachedItem(CacheKey, FeedXml, CacheTime, false);
            }
            else
                FeedXml = o.ToString();

            // Finally, write the feed to the response stream
            WriteFeed();
        }

        /// <summary>
        /// Writes the xml feed to the response stream.
        /// </summary>
        protected virtual void WriteFeed()
        {
            CommunityContext.Response.ContentEncoding = Encoding.UTF8;
            CommunityContext.Response.ContentType = "text/xml";
            CommunityContext.Response.Cache.SetCacheability(HttpCacheability.Public);
            CommunityContext.Response.Write(FeedXml);
        }

        #region IHttpHandler Members

        /// <summary>
        /// Used to process the Syndication request.
        /// </summary>
        /// <param name="context">The current context.</param>
        public void ProcessRequest(HttpContext context)
        {
            // We process the feed to process the request
            ProcessFeed();
        }

        /// <summary>
        /// Should the handler be kept in memory?
        /// </summary>
        public bool IsReusable
        {
            get { return false; }
        }

        #endregion
    }
}
