// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Configuration;

namespace DotCommunities.Framework.Configuration
{
    /// <summary>
    /// Configures the generic handler element in the web configuration file.
    /// </summary>
    public class GenericHandlerElement : ConfigurationElement
    {
        /// <summary>
        /// Creates a new <see cref="GenericHandlerElement"/>.
        /// </summary>
        public GenericHandlerElement() { }

        /// <summary>
        /// Creates a new <see cref="GenericHandlerElement"/>.
        /// </summary>
        /// <param name="name">The name of the generic handler.</param>
        public GenericHandlerElement(string name) 
            : this(name, null) { }

        /// <summary>
        /// Creates a new <see cref="GenericHandlerElement"/>.
        /// </summary>
        /// <param name="name">The name of the generic handler.</param>
        /// <param name="control">The name of the generic handler control.</param>
        public GenericHandlerElement(string name, string control)
            : this(name, control, null) { }

        /// <summary>
        /// Creates a new <see cref="GenericHandlerElement"/>.
        /// </summary>
        /// <param name="name">The name of the generic handler.</param>
        /// <param name="control">The name of the generic handler control.</param>
        /// <param name="extensionNames">The list of extension names that this handler uses.</param>
        public GenericHandlerElement(string name, string control, string extensionNames) 
        {
            Name = name;
            Control = control;
            ExtensionNames = extensionNames;
        }

        /// <summary>
        /// Gets or sets the name of the generic handler.
        /// </summary>
        [ConfigurationProperty("name", IsRequired = true, IsKey = true)]
        public string Name
        {
            get { return (string)this["name"]; }
            set { this["name"] = value; }
        }

        /// <summary>
        /// Gets or sets the generic handler control name.
        /// </summary>
        [ConfigurationProperty("control", IsRequired = true)]
        public string Control
        {
            get { return (string)this["control"]; }
            set { this["control"] = value; }
        }

        /// <summary>
        /// Gets or sets the list of extension names that this handler uses.
        /// </summary>
        [ConfigurationProperty("extensionNames", IsRequired = false)]
        public string ExtensionNames
        {
            get { return (string)this["extensionNames"]; }
            set { this["extensionNames"] = value; }
        }        
    }
}
