// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Configuration;

namespace DotCommunities.Framework.Configuration
{
    /// <summary>
    /// Configures the module page element in the web configuration file.
    /// </summary>
    public class ModulePageElement : ConfigurationElement
    {
        /// <summary>
        /// Creates a new <see cref="ModulePageElement"/>.
        /// </summary>
        public ModulePageElement() { }

        /// <summary>
        /// Creates a new <see cref="ModulePageElement"/>.
        /// </summary>
        /// <param name="name">The name of the module page.</param>
        public ModulePageElement(string name) 
            : this(name, null) { }

        /// <summary>
        /// Creates a new <see cref="ModulePageElement"/>.
        /// </summary>
        /// <param name="name">The name of the module page.</param>
        /// <param name="type">The <see cref="Type"/> of the module page.</param>
        public ModulePageElement(string name, string type)
            : this(name, type, null, null, false, false) { }

        /// <summary>
        /// Creates a new <see cref="ModulePageElement"/>.
        /// </summary>
        /// <param name="name">The name of the module page.</param>
        /// <param name="type">The <see cref="Type"/> of the module page.</param>
        /// <param name="title">The module page title.</param>
        /// <param name="description">The module page description.</param>
        /// <param name="isSection">Is the module page a section page.</param>
        /// <param name="isParent">Is the module page a parent page.</param>
        public ModulePageElement(string name, string type, string title, string description, bool isSection, bool isParent) 
        {
            Name = name;
            TypeName = type;
            Title = title;
            Description = description;
            IsSection = isSection;
            IsParent = isParent;
        }

        /// <summary>
        /// Gets or sets the name of the module page.
        /// </summary>
        [ConfigurationProperty("name", IsRequired = true, IsKey = true)]
        public string Name
        {
            get { return (string)this["name"]; }
            set { this["name"] = value; }
        }

        /// <summary>
        /// Gets or sets the <see cref="Type"/> of the module page.
        /// </summary>
        [ConfigurationProperty("type", IsRequired = true)]
        public string TypeName
        {
            get { return (string)this["type"]; }
            set { this["type"] = value; }
        }


        /// <summary>
        /// Gets or sets the module page title.
        /// </summary>
        [ConfigurationProperty("title", IsRequired = false)]
        public string Title
        {
            get { return (string)this["title"]; }
            set { this["title"] = value; }
        }

        /// <summary>
        /// Gets or sets the module page description.
        /// </summary>
        [ConfigurationProperty("description", IsRequired = false)]
        public string Description
        {
            get { return (string)this["description"]; }
            set { this["description"] = value; }
        }
        
        /// <summary>
        /// Gets or sets a value indicating if the module page a section page.
        /// </summary>
        [ConfigurationProperty("isSection", IsRequired = false)]
        public bool IsSection
        {
            get { return (bool)this["isSection"]; }
            set { this["isSection"] = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating if the module page a parent page. 
        /// </summary>
        [ConfigurationProperty("isParent", IsRequired = true)]
        public bool IsParent
        {
            get { return (bool)this["isParent"]; }
            set { this["isParent"] = value; }
        }
    }
}
