// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Configuration;

namespace DotCommunities.Framework.Configuration
{
    /// <summary>
    /// Configures the named page element in the web configuration file.
    /// </summary>
    public class NamedPageElement : ConfigurationElement
    {
        /// <summary>
        /// Creates a new <see cref="NamedPageElement"/>.
        /// </summary>
        public NamedPageElement() { }

        /// <summary>
        /// Creates a new <see cref="NamedPageElement"/>.
        /// </summary>
        /// <param name="name">The name of the named page.</param>
        public NamedPageElement(string name) 
            : this(name, null, null) { }

        /// <summary>
        /// Creates a new <see cref="NamedPageElement"/>.
        /// </summary>
        /// <param name="name">The name of the named page.</param>
        /// <param name="type">The <see cref="Type"/> of the named page.</param>
        /// <param name="path">The path of the named page.</param>
        public NamedPageElement(string name, string type, string path)
            : this(name, null, null, type, path) { }

        /// <summary>
        /// Creates a new <see cref="NamedPageElement"/>.
        /// </summary>
        /// <param name="name">The name of the named page.</param>
        /// <param name="title">The title of the named page.</param>
        /// <param name="description">The description of the named page.</param>
        /// <param name="type">The <see cref="Type"/> of the named page.</param>
        /// <param name="path">The path of the named page.</param>
        public NamedPageElement(string name, string title, string description, string type, string path) 
        {
            Name = name;
            Title = title;
            Description = description;
            TypeName = type;
            Path = path;
        }

        /// <summary>
        /// Gets or sets the name of the named page.
        /// </summary>
        [ConfigurationProperty("name", IsRequired = true, IsKey = true)]
        public string Name
        {
            get { return (string)this["name"]; }
            set { this["name"] = value; }
        }

        /// <summary>
        /// Gets or sets the title of the named page.
        /// </summary>
        [ConfigurationProperty("title", IsRequired = false)]
        public string Title
        {
            get { return (string)this["title"]; }
            set { this["title"] = value; }
        }

        /// <summary>
        /// Gets or sets the description of the named page.
        /// </summary>
        [ConfigurationProperty("description", IsRequired = false)]
        public string Description
        {
            get { return (string)this["description"]; }
            set { this["description"] = value; }
        }
        
        /// <summary>
        /// Gets or sets the <see cref="Type"/> of the named page.
        /// </summary>
        [ConfigurationProperty("type", IsRequired = true)]
        public string TypeName
        {
            get { return (string)this["type"]; }
            set { this["type"] = value; }
        }

        /// <summary>
        /// Gets or sets the path of the named page.
        /// </summary>
        [ConfigurationProperty("path", IsRequired = true)]
        public string Path
        {
            get { return (string)this["path"]; }
            set { this["path"] = value; }
        }
    }
}
