// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;

namespace DotCommunities.Framework
{
    /// <summary>
    /// Represents ratings for a content page.
    /// </summary>
    [Serializable]
    public class ContentRating
    {
        int contentPageID = -1;
        int yourRating = -1;
        int averageRating = -1;

        /// <summary>
        /// Represents the content page ID. 
        /// </summary>
        public int ContentPageID
        {
            get { return contentPageID; }
            set { contentPageID = value; }
        }

        /// <summary>
        /// Represents the current user's rating of the content page.
        /// </summary>
        public int YourRating
        {
            get { return yourRating; }
            set { yourRating = value; }
        }

        /// <summary>
        /// Represents the average rating of the content page.
        /// </summary>
        public int AverageRating
        {
            get { return averageRating; }
            set { averageRating = value; }
        }

        /// <summary>
        /// Initializes rating information. 
        /// </summary>
        public ContentRating() { }

        /// <summary>
        /// Initializes rating information.
        /// </summary>
        /// <param name="dr">An <see cref="IDataReader"/> object containing
        /// rating data.</param>
        public ContentRating(IDataReader dr)
        {
            contentPageID = (int)dr["ContentPage_ID"];
            yourRating = (int)dr["YourRating"];
            averageRating = (int)dr["AverageRating"];
        }
    }
}
