// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Managers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Lists the top categories associated with community content.
    /// </summary>
    public class CategoryMenu : CommunityControl
    {
        string skinFileName = "Categories_CategoryMenu.ascx";

        ContentList rptCategories;

        int cacheDuration = 10;
        int count = 5;

        /// <summary>
        /// Gets or sets the category count.
        /// </summary>
        /// <value>The category count.</value>
        public int Count
        {
            get { return count; }
            set { count = value; }
        }

        /// <summary>
        /// Gets or sets the cache duration.
        /// </summary>
        /// <value>The cache duration.</value>
        public int CacheDuration
        {
            get { return cacheDuration; }
            set { cacheDuration = value; }
        }

        /// <summary>
        /// The type of skin. For example Page, Control, Template
        /// </summary>
        /// <value></value>
        override protected string SkinType
        {
            get { return "ControlSkins"; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="T:CategoryMenu"/> class.
        /// </summary>
        public CategoryMenu() : base() 
        {
            // Assign a default template name
            if (SkinFileName == null)
                SkinFileName = skinFileName;
        }

        /// <summary>
        /// This method must be implemented by all derived controls. The
        /// inherited method retrieves all the controls that it needs from
        /// the skin.
        /// </summary>
        /// <param name="skin">The skin file containing the category controls.</param>
        override protected void InitializeSkin(Control skin)
        {
            if (CommunityContext.CurrentCommunitySettings.EnableCategoryMenu)
            {
                // Get the DataList from the Skin
                rptCategories = (ContentList)GetControl(skin, "Categories");
                rptCategories.EnableViewState = false;
                rptCategories.ItemDataBound += new ContentListItemEventHandler(Repeater_ItemDataBound);
            }
        }

        /// <summary>
        /// Raises the <see cref="E:Control.Load"/> event.
        /// </summary>
        /// <param name="e">The <see cref="T:EventArgs"/> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            if (CommunityContext.CurrentCommunitySettings.EnableCategoryMenu)
            {
                // Bind the results to the DataList
                rptCategories.DataSource = FrameworkManager.GetLatestCategories(cacheDuration);
                rptCategories.DataBind();
            }

            // Only show the control when we have content for it         
            this.Visible = rptCategories.DataSource.Count > 0;
        }

        /// <summary>
        /// Handles the ItemDataBound event of the Repeater control.
        /// </summary>
        /// <param name="s">The source of the event.</param>
        /// <param name="e">The <see cref="T:ContentListItemEventArgs"/> instance containing the event data.</param>
        private void Repeater_ItemDataBound(Object s, ContentListItemEventArgs e)
        {
            HyperLink categoryLink;
            Category categoryInfo;

            if (e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem)
            {
                categoryInfo = (Category)e.Item.DataItem;
                // Format the hyperlink
                categoryLink = (HyperLink)GetControl(e.Item, "Category");
                categoryLink.Text = categoryInfo.Name;
                categoryLink.NavigateUrl = string.Format("{0}Categories_Category.aspx?Category={1}", 
                    CommunityContext.ApplicationPath,
                    CommunityContext.Server.UrlEncode(categoryInfo.Name));
            }
        }
    }
}
