// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI;
using System.Web.UI.WebControls;

using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents the number of comments for a content item.
    /// </summary>
    public class CommentCountItem : WebControl
    {
        string _formatText = "{0} comments";

        /// <summary>
        /// Initializes a new instance of the <see cref="CommentCountItem"/> class.
        /// </summary>
        public CommentCountItem()
            : base()
        {
            CssClass = "CommentCountItem";
            EnableViewState = false;
        }

        /// <summary>
        /// Gets or sets the format text of the comment.
        /// </summary>
        /// <value>The format text.</value>
        public string FormatText
        {
            get { return _formatText; }
            set { _formatText = value; }
        }

        /// <summary>
        /// Raises the <see cref="Control.DataBinding" /> event.
        /// </summary>
        /// <param name="e">An <see cref="EventArgs" /> object that contains 
        /// the event data.</param>
        override protected void OnDataBinding(EventArgs e)
        {
            ContentItem item;

            if (NamingContainer is ContentItem)
                item = (ContentItem)NamingContainer;
            else
                item = (ContentItem)NamingContainer.NamingContainer;

            CommunityContent objContentInfo = (CommunityContent)item.DataItem;
            ViewState["CommentCount"] = objContentInfo.CommentCount;
        }

        /// <summary>
        /// Renders the control to the specified HTML writer if comments are enabled.
        /// </summary>
        /// <param name="writer">The <see cref="HtmlTextWriter"/> object that receives 
        /// the control content.</param>
        override protected void Render(HtmlTextWriter writer)
        {            
            if (CommunityContext.CurrentSection.EnableComments)
                base.Render(writer);
        }

        /// <summary>
        /// Renders the contents of the control to the specified writer. 
        /// This method is used primarily by control developers.
        /// </summary>
        /// <param name="writer">A <see cref="HtmlTextWriter"/> that represents the output stream to render HTML content on the client.</param>
        override protected void RenderContents(HtmlTextWriter writer)
        {
            writer.Write(String.Format(_formatText, ViewState["CommentCount"]));
        }
    }
}
