// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;

using DotCommunities.Framework.Designers;
using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Control used to display content links to add, edit, delete, move, comment
    /// and moderate comments.
    /// </summary>
    [Designer(typeof(CommunityDesigner))]
    public class CommentEditContentItem : WebControl
    {
        private CommunityUser objUserInfo;
        
        private string editUrl = null;

        private string editIcon = "~/Communities/Common/Images/Admin/Edit.gif";

        private string deleteUrl = "ContentPages_DeleteContentPage.aspx?id={0}&ReturnUrl={1}";
        private string deleteIcon = "~/Communities/Common/Images/Admin/Delete.gif";

        /// <summary>
        /// Creates a new instance of the <see cref="CommentEditContentItem"/> class.
        /// </summary>
        public CommentEditContentItem()
            : base(HtmlTextWriterTag.Table)
        {
            CssClass = "CommentEditContentItem";

            if (Context != null)
            {
                int contentPageID = CommunityContext.CurrentPage.PageID;
                // Set the edit url to include the comment page ID
                editUrl = String.Format("Comments_EditComment.aspx?id={0}", contentPageID) + "&cid={0}";
            }
        }

        /// <summary>
        /// Raises the <see cref="Control.DataBinding"/> event.
        /// </summary>
        /// <param name="e">An <see cref="EventArgs"/> object that contains 
        /// the event data.</param>
        override protected void OnDataBinding(EventArgs e)
        {
            ContentItem item;

            if (NamingContainer is ContentItem)
                item = (ContentItem)NamingContainer;
            else
                item = (ContentItem)NamingContainer.NamingContainer;

            CommunityContent objContentInfo = (CommunityContent)item.DataItem;
            ViewState["ContentPageID"] = objContentInfo.ContentPageID;
        }

        /// <summary>
        /// Renders the control to the specified HTML writer.
        /// </summary>
        /// <remarks>
        /// Only rendered if the user has edit or delete permissions.
        /// </remarks>
        /// <param name="writer">The <see cref="HtmlTextWriter"/> object that 
        /// receives the control content.</param>
        override protected void Render(HtmlTextWriter writer)
        {
            // Get UserInfo from context
            if (Context != null)
            {
                objUserInfo = CommunityContext.CurrentUser;

                if (objUserInfo.MayEdit || objUserInfo.MayDelete)
                    base.Render(writer);
            }
        }

        /// <summary>
        /// Renders the contents of the control to the specified writer. 
        /// This method is used primarily by control developers.
        /// </summary>
        /// <param name="writer">A <see cref="HtmlTextWriter"/> that represents the 
        /// output stream to render HTML content on the client.</param>
        override protected void RenderContents(HtmlTextWriter writer)
        {
            // Get contentpageID
            int _contentPageID = (int)ViewState["ContentPageID"];

            // open table row
            writer.RenderBeginTag(HtmlTextWriterTag.Tr);

            // Edit cell
            if (objUserInfo.MayEdit)
            {
                editUrl = String.Format(editUrl, _contentPageID);
                writer.RenderBeginTag(HtmlTextWriterTag.Td);
                writer.AddAttribute(HtmlTextWriterAttribute.Href, CommunityContext.CalculatePath(editUrl));
                writer.RenderBeginTag(HtmlTextWriterTag.A);
                writer.Write(String.Format("<img src=\"{0}\" border=\"0\" />", Page.ResolveUrl(editIcon)));
                writer.RenderEndTag();
                writer.RenderEndTag();
            }

            // Delete cell
            if (objUserInfo.MayDelete)
            {
                deleteUrl = String.Format(deleteUrl, _contentPageID, CommunityContext.CurrentSectionPath + "Default.aspx");
                writer.RenderBeginTag(HtmlTextWriterTag.Td);
                writer.AddAttribute(HtmlTextWriterAttribute.Href, CommunityContext.CalculatePath(deleteUrl));
                writer.RenderBeginTag(HtmlTextWriterTag.A);
                writer.Write(String.Format("<img src=\"{0}\" border=\"0\" />", Page.ResolveUrl(deleteIcon)));
                writer.RenderEndTag();
                writer.RenderEndTag();
            }

            writer.RenderEndTag();
        }
    }
}
