// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Designers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents the body text of a comment
    /// </summary>
    [Designer(typeof(CommunityDesigner))]
    public class CommentText : WebControl
    {
        string _text;

        /// <summary>
        /// Allows the text to be assigned.
        /// This property is used in previewing on the add comment page.
        /// </summary>
        public string Text
        {
            get { return _text; }
            set { _text = value; }
        }

        /// <summary>
        /// Retrieves the comment text from the context.
        /// </summary>
        public CommentText()
        {
            CssClass = "CommentText";

            // Get Comment object
            if (Context != null)
            {
                Comment objCommentInfo = (Comment)CommunityContext.CurrentContent;
                if (objCommentInfo != null)
                    _text = objCommentInfo.Text;
            }
        }

        /// <summary>
        /// Renders the comment text.
        /// </summary>
        /// <param name="writer">The <see cref="HtmlTextWriter"/> to output to.</param>
        override protected void RenderContents(HtmlTextWriter writer)
        {
            // we need the section for the transformations
            Section objSectionInfo = CommunityContext.CurrentSection;

            // display the content
            writer.Write(CommunityContext.FormatText(objSectionInfo.AllowCommentHtmlInput, objSectionInfo, _text));
        }
    }
}
