// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Designers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Abstract class for displaying a date in a template.
    /// This class handles issues with time conversions.
    /// </summary>
    [Designer(typeof(CommunityDesigner))]
    public abstract class DateItem : WebControl
    {
        private string _dateFormatString = "{0:f}";
        private bool _displayTimeZone = true;

        /// <summary>
        /// Stores date in view state.
        /// </summary>
        public DateTime Date
        {
            get { return (DateTime)ViewState["Date"]; }
            set { ViewState["Date"] = value; }
        }

        /// <summary>
        ///  Determines whether time zone is displayed.
        /// </summary>
        public bool DisplayTimeZone
        {
            get { return _displayTimeZone; }
            set { _displayTimeZone = value; }
        }

        /// <summary>
        /// Enables the date to be formatted.
        /// </summary>
        public string DateFormatString
        {
            get { return _dateFormatString; }
            set { _dateFormatString = value; }
        }

        /// <summary>
        /// Raises the <see cref="Control.DataBinding"/> event.
        /// </summary>
        /// <remarks>
        /// Get the date commented from container.
        /// </remarks>
        /// <param name="e">An <see cref="EventArgs"/> object that contains the event data.</param>
        override protected void OnDataBinding(EventArgs e)
        {
            ContentItem item;

            if (NamingContainer is ContentItem)
                item = (ContentItem)NamingContainer;
            else
                item = (ContentItem)NamingContainer.NamingContainer;

            CommunityContent objContentInfo = (CommunityContent)item.DataItem;

            AssignContentItem(objContentInfo);
        }

        /// <summary>
        /// Override this method to add an item to the Date property.
        /// </summary>
        /// <param name="contentInfo">The <see cref="CommunityContent"/> containing date information.</param>
        abstract protected void AssignContentItem(CommunityContent contentInfo);

        /// <summary>
        /// Renders the contents of the control to the specified writer. 
        /// This method is used primarily by control developers.
        /// </summary>
        /// <remarks>
        /// Note: We convert the date to the local server time.
        /// </remarks>
        /// <param name="writer">A <see cref="HtmlTextWriter"/> that represents the output stream to render HTML content on the client.</param>
        override protected void RenderContents(HtmlTextWriter writer)
        {
            writer.Write(String.Format(_dateFormatString, Date.AddHours(CommunityContext.UserTimeZoneOffset)));
            if (_displayTimeZone)
                writer.Write(String.Format(" <span class=\"TimeZone\">({0})</span>", CommunityContext.UserTimeZone));
        }
    }
}
