// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Designers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents the community logo.
    /// </summary>
    [Designer(typeof(CommunityDesigner))]
    public class Logo : WebControl 
    {
        // Control information
        private ImageAlign _align = ImageAlign.NotSet;
        private bool _isSectionLink = false;
        private int _border = 0;
        private string _alt = null;

        /// <summary>
        /// If true, the link of the logo points to the current
        /// section, otherwise it points to the site root.
        /// </summary>
        public bool IsSectionLink
        {
            get { return _isSectionLink; }
            set { _isSectionLink = value; }
        }

        /// <summary>
        /// Sets the alignment for the logo image.
        /// </summary>
        public ImageAlign Align
        {
            get { return _align; }
            set { _align = value; }
        }

        /// <summary>
        /// Sets the border size for the image.
        /// </summary>
        public int Border
        {
            get { return _border; }
            set { _border = value; }
        }

        /// <summary>
        /// Sets the alternative text for the image (if null, section
        /// description is used).
        /// </summary>
        public string Alt
        {
            get { return _alt; }
            set { _alt = value; }
        }

        /// <summary>
        /// Display the logo image.
        /// </summary>
        /// <param name="writer">The html writer to render to.</param>
        protected override void RenderContents(HtmlTextWriter writer) 
        {
            // Do we have a logo image?
            if (Context != null && (!string.IsNullOrEmpty(CommunityContext.CurrentSection.Logo.Trim())))
                RenderLogoImage(writer);
         }
        
        /// <summary>
        /// Render the logo image.
        /// </summary>
         /// <param name="writer">The html writer to render to.</param>
        void RenderLogoImage(HtmlTextWriter writer) 
        {
            // Get the default (Home) details
            string path = CommunityContext.ApplicationPath + CommunityContext.CommunityBasePage;
            string altText = CommunityContext.EnabledSections.DefaultSection.Description;

            // If we are creating a section logo then get the current
            // section details instead
            if (_isSectionLink)
            {
                path = CommunityContext.CurrentSection.Path;
                // Make sure the description is not blank before assigning it
                if (!string.IsNullOrEmpty(CommunityContext.CurrentSection.Description))
                    altText = CommunityContext.CurrentSection.Description;
            }

            // Override the section description if we have manually set
            // the alternative text
            if (!string.IsNullOrEmpty(_alt))
                altText = _alt;

            // Write the link anchor
            writer.AddAttribute(HtmlTextWriterAttribute.Href, path);
            writer.RenderBeginTag(HtmlTextWriterTag.A);

            // Write the image html
            writer.Write(String.Format(
                "<img src=\"{0}\" border=\"{1}\" align=\"{2}\" alt=\"{3}\" />",
                CommunityContext.CalculateGenericHandlersPath(CommunityContext.CurrentSection.Logo),
                _border,
                _align,
                altText));

            // Write the end tag for the anchor
            writer.RenderEndTag();
        }
    }
}
