// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI.WebControls;
using System.Text;

using DotCommunities.Framework.Managers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// A drop down list that displays time zones.
    /// </summary>
    public class TimeZoneDropDownList : DropDownList
    {
        private bool userTimeZones = false;

        /// <summary>
        /// Gets or sets a value indicating if only user timezones are listed.
        /// </summary>
        public bool UserTimeZones
        {
            get { return userTimeZones; }
            set { userTimeZones = value; }
        }

        /// <summary>
        /// Gets or sets the currently selected <see cref="Zone"/>
        /// </summary>
        public Zone SelectedZone
        {
            get 
            { 
                if (!string.IsNullOrEmpty(SelectedValue))
                    return TimeZoneManager.GetTimeZone(SelectedValue); 
                return null;
            }
            set
            {
                if (value != null && (!string.IsNullOrEmpty(value.ID)))
                    SelectedValue = value.ID;
            }
        }

        /// <summary>
        /// Adds the time zones to the drop down list items.
        /// </summary>
        /// <param name="e">The arguments for this event.</param>
        protected override void OnInit(EventArgs e)
        {
            // Call the base class
            base.OnInit(e);
            // Load the values into the list
            TimeZoneData zones = TimeZoneManager.GetTimeZones();
            if (zones != null && zones.Items != null)
                foreach (Zone zone in zones.Items)
                    if ((zone.IsUserZone && userTimeZones) || (!userTimeZones))
                        Items.Add(new ListItem(string.Format(
                            "{0} ({1} {2})",
                            zone.Description,
                            zone.ID,
                            zone.Offset.ToString()),
                            zone.ID.ToString()));
        }
    }
}
