// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// <see cref="T:Image"/> control that is used with the <see cref="T:ImageHandler"/> to 
    /// resize an image based on the size of the control.
    /// </summary>
    public class ThumbnailImage : Image
    {
        private int targetSize;
        private string imagePath;

        /// <summary>
        /// Gets or sets the target size of the image in pixels.
        /// </summary>
        [Category("Appearance")]
        public int TargetSize
        {
            get { return targetSize; }
            set { targetSize = value; }
        }

        /// <summary>
        /// Gets or sets the path of the image to display.
        /// </summary>
        [Category("Appearance")]
        public string ImagePath
        {
            get { return imagePath; }
            set { imagePath = value; }
        }

        /// <summary>
        /// Overriden. Gets the width of the control.
        /// </summary>
        public new Unit Width
        {
            get { return base.Width; }
        }

        /// <summary>
        /// Overriden. Gets the height of the control.
        /// </summary>
        public new Unit Height
        {
            get { return base.Height; }
        }

        /// <summary>
        /// Overriden. Image url is set internally by the control to include the target size.
        /// </summary>
        private new string ImageUrl
        {
            set { base.ImageUrl = value; }
        }

        /// <summary>
        /// Creates a new instance of the <see cref="ThumbnailImage"/> control.
        /// </summary>
        public ThumbnailImage()
            : base()
        {
            targetSize = -1;
            imagePath = null;
        }

        /// <summary>
        /// Configures the image url before rendering.
        /// </summary>
        /// <param name="e">The <see cref="EvantArgs"/> for this event.</param>
        protected override void  OnPreRender(EventArgs e)
        {
            // If there is no image specified, dont show the control
            if (string.IsNullOrEmpty(imagePath))
                this.Visible = false;
            else
            {
                // Figure out the query for width and height
                string imageSize = string.Empty;
                // Set the width
                if (targetSize > 0)
                    imageSize += string.Format("size={0}", targetSize);
                // Set the image url
                ImageUrl = string.Format("{0}{1}{2}", imagePath, imagePath.Contains("?") ? "&" : "?", imageSize);
                // load the base OnPreRender event
                base.OnPreRender(e);
            }
        }
    }
}
