// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI;
using System.Web.UI.WebControls;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Managers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents the default page for the Parent section. This class 
    /// displays a list of child sections.
    /// </summary>
    public class SectionListPage : ContentListPage 
    {
        // The name of the skin to use for this section
        string _skinFileName = "Sections_SectionList.ascx";
        // The name of the method that retrieves the list of content items
        GetContentItemsDelegate _getContentItems = new GetContentItemsDelegate(FrameworkManager.GetChildSections);

        /// <summary>
        /// Initializes a new instance of the <see cref="SectionListPage"/> class.
        /// </summary>
        public SectionListPage() 
            : base() 
        {
            // Setup the page data
            SkinFileName = _skinFileName;
            GetContentItems = _getContentItems;
        }

        /// <summary>
        /// Initialise the skin control by loading the child section count.
        /// </summary>
        /// <param name="skin">The section list page skin.</param>
        protected override void InitializeSkin(Control skin)
        {
            // Run the base method first to initialise the controls
            base.InitializeSkin(skin);
            // Set the total number of records for the control
            TotalRecords = FrameworkManager.GetChildSectionCount(CommunityContext.CurrentSection.SectionID);
        }
    }
}
