// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;

using DotCommunities.Framework.Designers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents a section title displayed in a template as a link.
    /// </summary>
    [Designer(typeof(CommunityDesigner))]
    public class SectionTitleLinkItem : WebControl
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SectionTitleLinkItem"/> class.
        /// </summary>
        public SectionTitleLinkItem()
            : base(HtmlTextWriterTag.A)
        {
            CssClass = "sectionTitleLinkItem";
            EnableViewState = false;
        }

        /// <summary>
        /// Gets or sets the section title in view state.
        /// </summary>
        /// <value>The section title.</value>
        public string Title
        {
            get
            {
                if (ViewState["Title"] == null)
                    return String.Empty;
                else
                    return (string)ViewState["Title"];
            }
            set { ViewState["Title"] = value; }
        }

        /// <summary>
        /// Gets or sets the section path in view state.
        /// </summary>
        /// <value>The section path.</value>
        public string Path
        {
            get
            {
                if (ViewState["Path"] == null)
                    return String.Empty;
                else
                    return (string)ViewState["Path"];
            }
            set { ViewState["Path"] = value; }
        }

        /// <summary>
        /// Raises the <see cref="DataBinding" /> event.
        /// </summary>
        /// <param name="e">An <see cref="EventArgs" /> object that contains the event data.</param>
        override protected void OnDataBinding(EventArgs e)
        {
            ContentItem item;

            if (NamingContainer is ContentItem)
                item = (ContentItem)NamingContainer;
            else
                item = (ContentItem)NamingContainer.NamingContainer;

            // Get section info from ChildSection object
            ChildSection objChildSectionInfo = (ChildSection)item.DataItem;
            Title = objChildSectionInfo.Title;
            Path = objChildSectionInfo.Path;
        }

        /// <summary>
        /// Adds HTML attributes and styles that need to be rendered to the specified <see cref="T:System.Web.UI.HtmlTextWriterTag"></see>. This method is used primarily by control developers.
        /// </summary>
        /// <param name="writer">A <see cref="HtmlTextWriter" /> that represents the output stream to render HTML content on the client.</param>
        protected override void AddAttributesToRender(HtmlTextWriter writer)
        {
            writer.AddAttribute(HtmlTextWriterAttribute.Href, Path);
            base.AddAttributesToRender(writer);
        }

        /// <summary>
        /// Renders the contents of the control to the specified writer. This method is used primarily by control developers.
        /// </summary>
        /// <param name="writer">A <see cref="HtmlTextWriter" /> that represents the output stream to render HTML content on the client.</param>
        override protected void RenderContents(HtmlTextWriter writer)
        {
            writer.Write(Title);
        }
    }
}
