// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Managers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// The syndication handler for a generic RSS feed.
    /// </summary>
    public class RssHandler : SyndicationHandlerBase
    {
        /// <summary>
        /// Key used to cache feeds.
        /// </summary>
        protected override string CacheKey
        {
            get
            {
                string result = string.Format("Community.RssFeed:CommunityID:{0}", CommunityContext.CurrentCommunity.ID);

                if (CommunityContext.CurrentSection != null && CommunityContext.CurrentSection.SectionID > 0)
                    result = string.Format("Community.RssFeed:CommunityID:{0}:SectionID:{1}", CommunityContext.CurrentCommunity.ID, CommunityContext.CurrentSection.SectionID);

                return result;
            }
        }

        /// <summary>
        /// Length of time in minutes to cache the feed.
        /// </summary>
        protected override int CacheTime
        {
            get { return 90; }
        }

        /// <summary>
        /// Builds the actual RSS Feed.
        /// </summary>
        /// <returns>The feed string in XML format.</returns>
        protected override string BuildFeed()
        {
            // Create the syndication info 
            Syndication syndicationInfo = new Syndication();

            // Get section info from context
            Section objSectionInfo = CommunityContext.CurrentSection;

            // Check whether syndicated feed
            if (!objSectionInfo.IsSectionSyndicated)
                throw new Exception("Not published as a syndicated feed.");

            // Get the feed description
            syndicationInfo.Title = objSectionInfo.Title;
            syndicationInfo.Description = objSectionInfo.Description;
            syndicationInfo.Link = CommunityContext.ResolveAbsoluteUrl(objSectionInfo.Path);

            // Get the feed items
            // TODO Max syndication items should be set for the section - hardcoded for now
            syndicationInfo.Items = FrameworkManager.GetSyndicationItems(objSectionInfo.SectionID, 20);

            // Create a new RssWriter to output the XML
            RssWriter writer = new RssWriter(syndicationInfo, objSectionInfo.Path);

            // Return the XML from the RssWriter
            return writer.GetXml();
        }
    }
}
