// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI;
using System.Web.UI.WebControls;

using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents the user logout page which enables users to
    /// signout from the community.
    /// </summary>
    public class Logout : CommunityControl
    {
        string _skinFileName = "Users_Logout.ascx";
        
        /// <summary>
        /// Calls the base <see cref="CommunityControl"/> constructor
        /// and assigns the default page skin. Also calls Logout
        /// method to signout the current user.
        /// Initializes a new instance of the <see cref="Logout"/> class.
        /// </summary>
        public Logout()
            : base()
        {
            // Assign a default skin file name
            if (SkinFileName == null)
                SkinFileName = _skinFileName;

            // Logout User
            CommunityUser.Logout();
        }

        /// <summary>
        /// Specifies the skins directory where this page's skin file is located.
        /// </summary>
        override protected string SkinType
        {
            get { return "ContentSkins"; }
        }

        /// <summary>
        /// Raises the <see cref="OnLoad" /> event.
        /// We need to redirect back to the same page to clear the authentication ticket.
        /// </summary>
        /// <param name="e">The <see cref="EventArgs" /> object that contains the event data.</param>
        override protected void OnLoad(EventArgs e)
        {
            if (Context.Request.QueryString["logout"] == null)
                Context.Response.Redirect("users_logout.aspx?logout=true");
        }

        /// <summary>
        /// This method must be implemented by all derived controls. The
        /// inherited method retrieves all the controls that it needs from
        /// the skin.
        /// </summary>
        /// <param name="skin">The control skin.</param>
        override protected void InitializeSkin(Control skin) { }

    }
}
