// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI;
using System.Web.UI.WebControls;

using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents the Register page. The Register page enables
    /// new users to register with a community.
    /// </summary>
    public class Register : CommunityControl
    {
        string _skinFileName = "Users_Register.ascx";

        RegisterForm ctlRegisterForm;
        Panel pnlInvalidUsername;
        Panel pnlInvalidEmail;
        Panel pnlRegisterSuccessful;
        Button btnRegister;

        /// <summary>
        /// Initializes a new instance of the <see cref="Register"/> class.
        /// </summary>
        public Register()
            : base()
        {
            // Assign a default skin file name
            if (SkinFileName == null)
                SkinFileName = _skinFileName;
        }

        /// <summary>
        /// Specifies the skins directory where this page's skin file is located.
        /// </summary>
        /// <value></value>
        override protected string SkinType
        {
            get { return "ContentSkins"; }
        }

        /// <summary>
        /// This method must be implemented by all derived controls. The
        /// inherited method retrieves all the controls that it needs from
        /// the skin.
        /// </summary>
        /// <param name="skin">The skin control to initialise.</param>
        override protected void InitializeSkin(Control skin)
        {
            // Find the Register Form control
            ctlRegisterForm = (RegisterForm)GetControl(skin, "ctlRegisterForm");

            // Find the Invalid Username Panel
            pnlInvalidUsername = (Panel)GetControl(skin, "pnlInvalidUsername");
            pnlInvalidUsername.Visible = false;

            // Find the Invalid Email Panel
            pnlInvalidEmail = (Panel)GetControl(skin, "pnlInvalidEmail");
            pnlInvalidEmail.Visible = false;

            // Find the Invalid Email Panel
            pnlRegisterSuccessful = (Panel)GetControl(skin, "pnlRegisterSuccessful");
            pnlRegisterSuccessful.Visible = false;

            // Find Register Button
            btnRegister = (Button)GetControl(skin, "btnRegister");
            btnRegister.Click += new EventHandler(btnRegister_Click);
        }

        /// <summary>
        /// If no validation errors, registers user as a new user.
        /// </summary>
        /// <param name="s">The source of the event.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        void btnRegister_Click(Object s, EventArgs e)
        {
            if (Page.IsValid)
            {
                // TODO Password question & answer
                int result = CommunityUser.RegisterUser(
                                    ctlRegisterForm.Username.Trim(), 
                                    ctlRegisterForm.Password.Trim(), 
                                    ctlRegisterForm.Email.Trim(),
                                    null,
                                    null);

                if (result > 0)
                {
                    // If duplicate user let user know.
                    pnlInvalidUsername.Visible = result == 1;
                    pnlInvalidEmail.Visible = result == 2;
                }
                else
                {
                    // If successful then let user know
                    pnlRegisterSuccessful.Visible = result == 0;
                    ctlRegisterForm.Visible = !pnlRegisterSuccessful.Visible;
                }
            }
        }
    }
}
