// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web.UI;
using System.Web.UI.WebControls;

using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Represents the user registration form.
    /// </summary>
    public class RegisterForm : CommunityControl
    {
        string _skinFileName = "Users_RegisterForm.ascx";

        TextBox txtUsername;
        TextBox txtPassword;
        TextBox txtPasswordAgain;
        TextBox txtEmail;

        /// <summary>
        /// Gets or sets the username.
        /// </summary>
        /// <value>The username.</value>
        public string Username
        {
            get { return txtUsername.Text; }
            set
            {
                EnsureChildControls();
                txtUsername.Text = value;
            }
        }

        /// <summary>
        /// Gets or sets the password.
        /// </summary>
        /// <value>The password.</value>
        public string Password
        {
            get { return txtPassword.Text; }
            set
            {
                EnsureChildControls();
                txtPassword.Attributes["value"] = value;
                txtPasswordAgain.Attributes["value"] = value;
            }
        }

        /// <summary>
        /// Gets or sets the email.
        /// </summary>
        /// <value>The email.</value>
        public string Email
        {
            get { return txtEmail.Text; }
            set
            {
                EnsureChildControls();
                txtEmail.Text = value;
            }
        }

        /// <summary>
        /// Specifies the skins directory where this page's skin file is located.
        /// </summary>
        /// <value>Returns the value "ControlSkins".</value>
        override protected string SkinType
        {
            get { return "ControlSkins"; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="RegisterForm"/> class.
        /// </summary>
        public RegisterForm()
            : base()
        {
            // Assign a default template name
            if (SkinFileName == null)
                SkinFileName = _skinFileName;
        }

        /// <summary>
        /// This method must be implemented by all derived controls. The
        /// inherited method retrieves all the controls that it needs from
        /// the skin.
        /// </summary>
        /// <param name="skin">The control skin.</param>
        override protected void InitializeSkin(Control skin)
        {
            // Find the Username TextBox
            txtUsername = (TextBox)GetControl(skin, "txtUsername");

            // Find the Password TextBox
            txtPassword = (TextBox)GetControl(skin, "txtPassword");

            // Find the Password Again TextBox
            txtPasswordAgain = (TextBox)GetControl(skin, "txtPasswordAgain");

            // Find the Email TextBox
            txtEmail = (TextBox)GetControl(skin, "txtEmail");
        }
    }
}