// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Collections.Generic;

using DotCommunities.Framework.Managers;

namespace DotCommunities.Framework.Controls
{
    /// <summary>
    /// Catalog part that retrieves simple web parts from the WebParts
    /// directory in the communities folder.
    /// </summary>
    public class CommunityCatalogPart : CatalogPart
    {
        /// <summary>
        /// Gets web part descriptions from the file name.
        /// </summary>
        /// <returns>A <see cref="WebPartDescriptionCollection"/> containing web parts.</returns>
        public override WebPartDescriptionCollection GetAvailableWebPartDescriptions()
        {
            if (Context != null)
            {
                List<WebPartDescription> wpDescriptions = new List<WebPartDescription>();

                //Generate a list of available web parts that shows 
                //up in the catalog, each with a unique ID
                foreach (string webPart in WebPartsManager.GetAllWebParts())
                {
                    string webPartID = string.Format("{0}ID", webPart.Replace(' ', '_').Replace('(', '_').Replace(')', '_'));
                    wpDescriptions.Add(new WebPartDescription(webPartID, webPart, null, null));
                }

                return new WebPartDescriptionCollection(wpDescriptions);
            }

            // Return null if we do not have a context
            return null;
        }

        /// <summary>
        /// Creates a web part from the filename.
        /// </summary>
        /// <param name="description">The selected <see cref="WebPartDescription"/>.</param>
        /// <returns>A new <see cref="WebPart"/> from the file.</returns>
        public override WebPart GetWebPart(WebPartDescription description)
        {
            if (Context != null)
            {
                string path = WebPartsManager.GetWebPartPath(description.Title);
                if (!string.IsNullOrEmpty(path))
                {
                    // Load the web part control from the path                
                    Control partControl = Page.LoadControl(path);
                    if (partControl != null)
                    {
                        // Set the ID of the control for the web part manager
                        partControl.ID = description.ID;
                        // Add the web part to the manager
                        GenericWebPart webPart = WebPartManager.CreateWebPart(partControl);
                        if (webPart != null)
                        {
                            // Setup the web part
                            webPart.Title = description.Title;
                            webPart.TitleIconImageUrl = "~/Communities/Common/Images/WebParts/WebPart.png";
                            // Return an instance of the selected web part
                            return webPart;
                        }
                    }
                }
            }

            // If we have no path then we cannot load the part
            return null;
        }
    }
}
