// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;

using DotCommunities.Framework.Enums;

namespace DotCommunities.Framework
{
    /// <summary>
    /// This class represents all the information about the page being requested regardless 
    /// of whether the page is a named page, the default section page, or a content page.
    /// This class is used to add all the standard page elements to each page.
    /// </summary>
    public class GenericPage
    {
        private int pageID;
        private int parentID;

        private PageType pageType;

        private string contentType;
        private string name;
        private string title = String.Empty;
        private string description;
        private string metaDescription;
        private string metaKeys;

        #region Public Properties
        /// <summary>
        /// Gets the page ID.
        /// </summary>
        public int PageID 
        {
            get { return pageID; }
        }

        /// <summary>
        /// Gets the parent page ID.
        /// </summary>
        public int ParentID 
        {
            get { return parentID; }
        }

        /// <summary>
        /// Gets the type of generic page.
        /// </summary>
        public PageType PageType
        {
            get { return pageType; }
        }

        /// <summary>
        /// Gets or sets the content type name.
        /// </summary>
        public string ContentType
        {
            get { return contentType; }
            set { contentType = value; }
        }

        /// <summary>
        /// Gets the page name.
        /// </summary>
        public string Name
        {
            get { return name; }
        }

        /// <summary>
        /// Gets the page title.
        /// </summary>
        public string Title 
        {
            get { return title; }
        }

        /// <summary>
        /// Gets the page description.
        /// </summary>
        public string Description 
        {
            get { return description; }
        }

        /// <summary>
        /// Gets the title and description for selecting from a list.
        /// </summary>
        public string TitleAndDescription
        {
            get { return string.Format("<strong>{0}</strong> - {1}", title, description); }
        }

        /// <summary>
        /// Gets the meta description.
        /// </summary>
        public string MetaDescription
        {
            get { return metaDescription; }
        }

        /// <summary>
        /// Gets the meta keys.
        /// </summary>
        public string MetaKeys 
        {
            get { return metaKeys; }
        }
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="GenericPage"/> class.
        /// </summary>
        /// <param name="pageID">The page ID.</param>
        /// <param name="parentID">The parent ID.</param>
        /// <param name="pageType">The name of the page type.</param>
        /// <param name="contentType">The content type.</param>
        /// <param name="name">The page name.</param>
        /// <param name="title">The page title.</param>
        /// <param name="description">The page description.</param>
        /// <param name="metaDescription">The meta description.</param>
        /// <param name="metaKeys">The meta keys.</param>
        public GenericPage
        (
            int pageID,
            int parentID,
            PageType pageType,
            string contentType,
            string name,
            string title,
            string description,
            string metaDescription,
            string metaKeys
        )
        {
            this.pageID = pageID;
            this.parentID = parentID;
            this.pageType = pageType;
            this.contentType = contentType;
            this.name = name;
            this.title = title;
            this.description = description;
            this.metaDescription = metaDescription;
            this.metaKeys = metaKeys;
        }
    }
}
