// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Data.Common;

namespace DotCommunities.Framework.Interfaces
{
    /// <summary>
    /// Interface for creating data access commands with provider helper functions.
    /// </summary>
    public interface IProviderHelper
    {
        /// <summary>
        /// Returns a <see cref="DbCommand"/> object containing the discovered parameters of a stored procedure.
        /// </summary>
        /// <param name="name">The name of the stored procedure to invoke.</param>
        /// <returns>A <see cref="DbCommand"/> object containing the correct parameters for the stored procedure.</returns>
        DbCommand CreateCommand(string name);

        /// <summary>
        /// Returns a <see cref="DbCommand"/> object containing the discovered parameters of a stored procedure.
        /// </summary>
        /// <param name="name">The name of the stored procedure to invoke.</param>
        /// <param name="values">An parameterised list of values required by the stored procedure.</param>
        /// <returns>A <see cref="DbCommand"/> object containing the correct parameters for the stored procedure.</returns>
        DbCommand CreateCommand(string name, params object[] values);

        /// <summary>
        /// Returns a <see cref="DataSet"/> of results from the database.
        /// </summary>
        /// <param name="command">The <see cref="DbCommand"/> to execute.</param>
        /// <returns>A <see cref="DataSet"/> containing the retrieved data.</returns>
        DataSet ExecuteDataSet(DbCommand command);

        /// <summary>
        /// Returns an <see cref="IDataReader"/> for the command.
        /// </summary>
        /// <remarks>
        /// Connection needs to be closed manually (can be manually disposed by wrapping call around a <c>using</c> statement).
        /// </remarks>
        /// <param name="command">The <see cref="DbCommand"/> to execute.</param>
        /// <returns>An <see cref="IDataReader"/> containing the retrieved data.</returns>
        IDataReader CreateReader(DbCommand command);

        /// <summary>
        /// Executes a command.
        /// </summary>
        /// <param name="command">The <see cref="DbCommand"/> to execute.</param>
        /// <returns>The return value of the command.</returns>
        int Execute(DbCommand command);
    }
}
