// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.IO;
using System.Collections.Generic;

using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Managers
{
    /// <summary>
    /// Manages page layout page data.
    /// </summary>
    public class LayoutManager
    {
        /// <summary>
        /// Gets all layout pages.
        /// </summary>
        /// <returns>A list of all available layout pages.</returns>
        public static List<string> GetAllLayouts()
        {
            List<string> colLayouts = new List<string>();

            // Get contents from common folder
            string layoutsFolder = CommunityContext.Context.Server.MapPath(CommunityContext.ApplicationPath + "/Communities/Common/Layouts");

            string[] arrLayoutFiles = Directory.GetFiles(layoutsFolder, "*.ascx");
            foreach (string strFileName in arrLayoutFiles)
                colLayouts.Add(Path.GetFileNameWithoutExtension(strFileName));

            // Get contents from community folder
            layoutsFolder = CommunityContext.Context.Server.MapPath(String.Format("{0}/Communities/{1}/Layouts/", CommunityContext.ApplicationPath, CommunityContext.CurrentCommunity.Name));
            if (Directory.Exists(layoutsFolder))
            {
                arrLayoutFiles = Directory.GetFiles(layoutsFolder, "*.ascx");
                foreach (string strFileName in arrLayoutFiles)
                    colLayouts.Add(String.Format("{0} ({1})", Path.GetFileNameWithoutExtension(strFileName), CommunityContext.CurrentCommunity.Name));
            }

            return colLayouts;
        }

        /// <summary>
        /// Gets the path to the layout file.
        /// </summary>
        /// <param name="layout">The name of the layout file.</param>
        /// <returns>The path for the layout file.</returns>
        public static string GetLayoutPath(string layout)
        {
            string communityIdentifier = String.Format(" ({0})", CommunityContext.CurrentCommunity.Name);
            if (layout.EndsWith(communityIdentifier))
                return String.Format("~/Communities/{0}/Layouts/{1}.ascx", CommunityContext.CurrentCommunity.Name, layout.Replace(communityIdentifier, string.Empty));
            else
                return String.Format("~/Communities/Common/Layouts/{0}.ascx", layout);
        }    
    }
}
