// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Collections.Generic;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Properties;

namespace DotCommunities.Framework.Managers
{
    /// <summary>
    /// Manages quote data for the <see cref="FrameworkProvider"/>.
    /// </summary>
    public partial class FrameworkManager : FrameworkManagerBase
    {
        /// <summary>
        /// Administration data object to add a new quote.
        /// </summary>
        /// <param name="quote_Text">The text to add.</param>
        /// <returns>The new quote ID.</returns>
        public static int AddQuote(string quote_Text)
        {
            try
            {
                return Provider.AddQuote(CommunityContext.CurrentCommunity.ID, quote_Text);
            }
            finally
            {
                ClearQuotes();
            }
        }

        /// <summary>
        /// Administration data object to edit an existing quote.
        /// </summary>
        /// <param name="quote_ID">The quote ID of the quote to edit.</param>
        /// <param name="quote_Text">The quote text to update.</param>
        public static void EditQuote(int quote_ID, string quote_Text)
        {
            try
            {
                Provider.EditQuote(CommunityContext.CurrentCommunity.ID, quote_ID, quote_Text);
            }
            finally
            {
                ClearQuotes();
            }
        }

        /// <summary>
        /// Administration data object to delete an existing quote.
        /// </summary>
        /// <param name="quote_ID">The quote ID of the quote to delete.</param>
        public static void DeleteQuote(int quote_ID)
        {
            try
            {
                Provider.DeleteQuote(CommunityContext.CurrentCommunity.ID, quote_ID);
            }
            finally
            {
                ClearQuotes();
            }
        }

        /// <summary>
        /// Retrieves all quote data from the Quotes table.
        /// </summary>
        /// <returns>A table of quotes.</returns>
        public static DataTable GetQuotes()
        {
            string cacheKey = string.Format(Resources.QuotesCacheKey, CommunityContext.CurrentCommunity.ID);

            object item = GetCachedItem(cacheKey);

            if (item != null && item is DataTable)
                return (DataTable)item;

            return (DataTable)AddCachedItem(cacheKey, Provider.GetQuotes(CommunityContext.CurrentCommunity.ID).Tables[0]);
        }

        /// <summary>
        /// Retrieves all quotes from the Quotes table.
        /// </summary>
        /// <returns>A list of quotes.</returns>
        public static List<string> GetAllQuotes()
        {
            List<string> quotes = new List<string>();

            foreach (DataRow dr in GetQuotes().Rows)
                quotes.Add(dr["Quote_Text"].ToString());

            return quotes;
        }

        /// <summary>
        /// Removes the cached quote data from the cache.
        /// </summary>
        static void ClearQuotes()
        {
            RemoveCachedItem(string.Format(Resources.QuotesCacheKey, CommunityContext.CurrentCommunity.ID));
        }
    }
}
