// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;

using DotCommunities.Framework.Properties;
using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Managers
{
    /// <summary>
    /// Manages content page data for the <see cref="FrameworkProvider"/>.
    /// </summary>
    public partial class FrameworkManager : FrameworkManagerBase
    {
        /// <summary>
        /// Removes rating data from both the content page and the comments caches.
        /// </summary>
        /// <param name="contentPageID">The current content page ID.</param>
        /// <param name="userName">The current username for user rating info.</param>
        private static void ClearRatings(int contentPageID, string userName)
        {
            // Build the rating cache key
            string cacheKey = string.Format(Resources.ContentRatingCacheKey, contentPageID, userName);

            // Remove the rating from the cache so that we reload it with new ratings
            RemoveCachedItem(cacheKey);
        }

        /// <summary>
        /// Retrieves the content ratings for the specified content page ID.
        /// </summary>
        /// <param name="contentPageID">The content page ID to retrieve ratings for.</param>
        /// <param name="userName">The current username for user rating info.</param>
        /// <returns>A <see cref="ContentRating"/> object containing rating information.</returns>
        public static ContentRating GetRatings(int contentPageID, string userName)
        {
            // Build the rating cache key
            string cacheKey = string.Format(Resources.ContentRatingCacheKey, contentPageID, userName);

            object item = GetCachedItem(cacheKey);

            if (item != null)
                return (ContentRating)item;

            return (ContentRating)AddCachedItemFor60Seconds(cacheKey, Provider.GetRatings(CommunityContext.CurrentCommunity.ID, contentPageID, userName));
        }

        /// <summary>
        /// Adds a new user rating to a content item in the database.
        /// </summary>
        /// <param name="contentPageID">The content page ID to be rated.</param>
        /// <param name="userName">The user who rated the content.</param>
        /// <param name="rating">The rating the user has given for the content.</param>
        /// <returns>The updated average rating for the content.</returns>
        public static int AddRating(int sectionID, int contentPageID, string userName, int rating)
        {
            // Clear the cache of old rating data
            ClearRatings(contentPageID, userName);

            // Retrieve the new average rating from the cache
            return Provider.AddRating(CommunityContext.CurrentCommunity.ID, contentPageID, userName, rating);
        }
    }
}
