// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections.Generic;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Properties;

namespace DotCommunities.Framework.Managers
{
    /// <summary>
    /// Manages redirect data for the <see cref="FrameworkProvider"/>.
    /// </summary>
    public partial class FrameworkManager : FrameworkManagerBase
    {
        /// <summary>
	    /// Gets redirection generic list from cache if present; otherwise from the provider.
	    /// </summary>
        /// <returns>
        /// A generic list containing <see cref="Redirect"/> instances for all redirects 
        /// in the community.
        /// </returns>
	    public static List<Redirect> GetRedirects()
	    {
            string cacheKey = string.Format(Resources.RedirectsCacheKey, CommunityContext.CurrentCommunity.ID);

            object item = GetCachedItem(cacheKey);

            if (item != null)
                return (List<Redirect>)item;

            // Delegate to the provider
            return (List<Redirect>)AddCachedItemFor24Hrs(cacheKey, Provider.GetRedirects(CommunityContext.CurrentCommunity.ID));
	    }

        /// <summary>
        /// Calculates the supplied requestPath to determine if it should be redirected.
        /// </summary>
        /// <param name="requestUrl">A <see cref="Url"/> containing the requested path.</param>
        /// <returns><c>null</c>, if no redirection found; otherwise a string URL of the destination redirection.</returns>
        public static string CalculateRedirects(Uri requestUrl)
        {
            string redirectUrl = null;
            string requestPage = CommunityContext.GetPageName(requestUrl.AbsolutePath);
            string requestSection = CommunityContext.GetSectionPath(requestUrl.AbsolutePath);

            List<Redirect> RedirectList = GetRedirects();

            RedirectList.Sort(); // Puts the page targeted items first.

            foreach (Redirect ri in RedirectList)
            {
                string sourcePage = CommunityContext.ApplicationPath + ri.SourceUrl;
                string destinationPage = CommunityContext.GetPageName(CommunityContext.ApplicationPath + ri.DestinationUrl);

                // Set page targets
                if (sourcePage.ToLower() == requestUrl.AbsolutePath.ToLower())
                {
                    if (ri.DestinationUrl.ToLower().StartsWith("http://"))
                        redirectUrl = ri.DestinationUrl;
                    else
                        redirectUrl = (CommunityContext.ApplicationPath + ri.DestinationUrl).Replace(requestPage, destinationPage);

                    // Go to next redirect
                    break;
                }

                // Set section targets
                if (sourcePage.ToLower() == requestSection.ToLower())
                {
                    if (ri.DestinationUrl.ToLower().StartsWith("http://"))
                    {
                        if (ri.DestinationUrl.ToLower().EndsWith("/"))
                            redirectUrl = ri.DestinationUrl + requestPage.Substring(1, requestPage.Length - 1);
                        else
                            redirectUrl = ri.DestinationUrl;
                    }
                    else
                    {
                        if (ri.DestinationUrl.ToLower().EndsWith("/"))
                            redirectUrl = (CommunityContext.ApplicationPath + ri.DestinationUrl) + requestPage.Substring(1, requestPage.Length - 1);
                        else
                            redirectUrl = (CommunityContext.ApplicationPath + ri.DestinationUrl);
                    }

                    // Go to next redirect
                    break;
                }
            }

            // Return the url
            return redirectUrl;
        }
    }
}
