// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.IO;
using System.Collections.Generic;

using DotCommunities.Framework.Components;

namespace DotCommunities.Framework.Managers
{
    /// <summary>
    /// Manages web part page data.
    /// </summary>
    public class WebPartsManager
    {
        /// <summary>
        /// Gets all web part pages.
        /// </summary>
        /// <returns>A list of all available web part pages.</returns>
        public static List<string> GetAllWebParts()
        {
            List<string> colWebParts = new List<string>();

            // Get contents from common folder
            string webPartsFolder = CommunityContext.Context.Server.MapPath(CommunityContext.ApplicationPath + "/Communities/Common/WebParts");

            string[] arrWebPartFiles = Directory.GetFiles(webPartsFolder, "*.ascx");
            foreach (string strFileName in arrWebPartFiles)
                colWebParts.Add(Path.GetFileNameWithoutExtension(strFileName));

            // Get contents from community folder
            webPartsFolder = CommunityContext.Context.Server.MapPath(String.Format("{0}/Communities/{1}/WebParts/", CommunityContext.ApplicationPath, CommunityContext.CurrentCommunity.Name));
            if (Directory.Exists(webPartsFolder))
            {
                arrWebPartFiles = Directory.GetFiles(webPartsFolder, "*.ascx");
                foreach (string strFileName in arrWebPartFiles)
                    colWebParts.Add(String.Format("{0} ({1})", Path.GetFileNameWithoutExtension(strFileName), CommunityContext.CurrentCommunity.Name));
            }

            return colWebParts;
        }

        /// <summary>
        /// Gets the path to the web part file.
        /// </summary>
        /// <param name="webPart">The name of the web part file.</param>
        /// <returns>The path for the web part file.</returns>
        public static string GetWebPartPath(string webPart)
        {
            string communityIdentifier = String.Format(" ({0})", CommunityContext.CurrentCommunity.Name);
            if (webPart.EndsWith(communityIdentifier))
                return String.Format("~/Communities/{0}/WebParts/{1}.ascx", CommunityContext.CurrentCommunity.Name, webPart.Replace(communityIdentifier, string.Empty));
            else
                return String.Format("~/Communities/Common/WebParts/{0}.ascx", webPart);
        }
    }
}
