// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Configuration.Provider;
using System.Collections.Specialized;

using DotCommunities.Framework.Properties;
using DotCommunities.Framework.Interfaces;

namespace DotCommunities.Framework.Providers
{
    /// <summary>
    /// Provider for text editors of type <see cref="ITextEditor"/>.
    /// </summary>
    public abstract class TextEditorProvider : ProviderBase
    {
        private string name;
        private string providerType;
        
        /// <summary>
        /// The name of the provider.
        /// </summary>
        public override string Name
        {
            get { return name; }
        }

        /// <summary>
        /// The type of the provider.
        /// </summary>
        public string ProviderType
        {
            get { return providerType; }
        }

        /// <summary>
        /// Initialises the provider. Overloaded from <see cref="ProviderBase"/>
        /// </summary>
        /// <param name="name">The name of the provider.</param>
        /// <param name="config">A collection of <see cref="NameValueCollection"/> configureation values.</param>
        public override void Initialize(string name, NameValueCollection config)
        {
            // Verify that config isn't null
            if (config == null)
                throw new ArgumentNullException("config");

            // Assign the provider a default name if it doesn't have one
            if (String.IsNullOrEmpty(name))
                name = "FckEditorProvider";
            this.name = name;

            // Add a default "description" attribute to config if the
            // attribute doesn't exist or is empty
            if (string.IsNullOrEmpty(config["description"]))
            {
                config.Remove("description");
                config.Add("description", Resources.TextEditorProviderDescription);
            }

            // Call the base class's Initialize method
            base.Initialize(name, config);

            // Initialize providerType
            providerType = config["providerType"];

            if (string.IsNullOrEmpty(providerType))
                providerType = "TextEditor";

            config.Remove("providerType");

            // Throw an exception if unrecognized attributes remain
            if (config.Count > 0)
            {
                string attr = config.GetKey(0);
                if (!String.IsNullOrEmpty(attr))
                    throw new ProviderException(string.Format(Resources.UnrecognisedProviderAttributeException, attr));
            }
        }

        /// <summary>
        /// Abstract method that when overriden will return a compatible <see cref="ITextEditor"/> control.
        /// </summary>
        /// <returns>A compatible <see cref="ITextEditor"/> control.</returns>
        public abstract ITextEditor GetEditor();
    }
}
