// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;

using DotCommunities.Framework.Enums;

namespace DotCommunities.Framework
{
    /// <summary>
    ///  Represents all the information about a service. A service
    /// can be either a community Web service or an RSS services.
    /// </summary>
    public class Service
    {
        int _id;
        string _name;
        string _url;
        ServiceType _serviceType;
        int _maximumItems;
        int _refreshRate;
        string _password;
        DateTime _dateLastRefreshed;

        /// <summary>
        ///  Represents the ID of the service.
        /// </summary>
        public int ID
        {
            get { return _id; }
            set { _id = value; }
        }

        /// <summary>
        /// Represents the name of the service.
        /// </summary>
        public string Name
        {
            get { return _name; }
            set { _name = value; }
        }

        /// <summary>
        /// Represents the URL of the service.
        /// </summary>
        public string Url
        {
            get { return _url; }
            set { _url = value; }
        }

        /// <summary>
        ///  Represents the type of the service such as community Web 
        /// service or RSS.
        /// </summary>
        public ServiceType ServiceType
        {
            get { return _serviceType; }
            set { _serviceType = value; }
        }

        /// <summary>
        /// Represents how often the service is called (in minutes).
        /// </summary>
        public int RefreshRate
        {
            get { return _refreshRate; }
            set { _refreshRate = value; }
        }

        /// <summary>
        /// Represents the number of items returned by the service.
        /// </summary>
        public int MaximumItems
        {
            get { return _maximumItems; }
            set { _maximumItems = value; }
        }

        /// <summary>
        /// Represents the password required to call the service.
        /// </summary>
        public string Password
        {
            get { return _password; }
            set { _password = value; }
        }

        /// <summary>
        /// Represents the date and time the service was last called.
        /// </summary>
        public DateTime DateLastRefreshed
        {
            get { return _dateLastRefreshed; }
            set { _dateLastRefreshed = value; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Service"/> object.
        /// </summary>
        public Service() { }

        /// <summary>
        /// Initializes a new instance of the <see cref="Service"/> object.
        /// </summary>
        /// <param name="dr">An <see cref="IDataReader"/> containing row data.</param>
        public Service(IDataReader dr)
        {
            this.ID = (int)dr["Service_ID"];
            this.Name = (string)dr["Service_Name"];
            this.Url = (string)dr["Service_Url"];
            this.Password = (string)dr["Service_Password"];
            this.ServiceType = (ServiceType)dr["Service_Type"];
            this.MaximumItems = (int)dr["Service_MaxItems"];
            this.RefreshRate = (int)dr["Service_RefreshRate"];
            this.DateLastRefreshed = (DateTime)dr["Service_DateLastRefreshed"];
        }
    }
}
