// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Data.Common;

using Microsoft.Practices.EnterpriseLibrary.Data;

namespace DotCommunities.Framework.Providers
{
    /// <summary>
    /// Partial class for the implementation of the <see cref="FrameworkProvider"/> abstract class.
    /// </summary>
    public partial class SqlFrameworkProvider : FrameworkProvider
    {
        public override ContentPage GetContentPage(int contentPageID, int sectionID)
        {
            ContentPage contentPageInfo = null;

            using (IDataReader dr = CreateReader(CreateCommand("Community_ContentPagesGetContentPage", contentPageID, sectionID)))
                if (dr.Read())
                    contentPageInfo = new ContentPage(dr);

            return contentPageInfo;
        }

        public override int GetTotalContentPages(int sectionID)
        {
            return Execute(CreateCommand("Community_ContentPagesGetTotalRecords", sectionID));
        }

        public override DataSet GetNewContent(int communityID, string contentType, int returnCount)
        {
            return ExecuteDataSet(CreateCommand("Community_ContentPagesGetNewContent", communityID, contentType, returnCount));
        }

        public override DataSet GetPopularContent(int communityID, string contentType, int returnCount)
        {
            return ExecuteDataSet(CreateCommand("Community_ContentPagesGetPopularContent", communityID, contentType, returnCount));
        }

        public override void MoveContentUp(int contentPageID)
        {
            Execute(CreateCommand("Community_ContentPagesMoveContentUp", contentPageID));
        }

        public override void MoveContentDown(int contentPageID)
        {
            Execute(CreateCommand("Community_ContentPagesMoveContentDown", contentPageID));
        }
    }
}
