// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;

namespace DotCommunities.Framework.Providers
{
    /// <summary>
    /// Partial class for the implementation of the <see cref="FrameworkProvider"/> abstract class.
    /// </summary>
    public partial class SqlFrameworkProvider : FrameworkProvider
    {
        public override ImageData GetSectionImage(int communityID, int sectionID, int imageID, int width, int height, bool isThumbnail)
        {
            ImageData sectionImageInfo = null;

            using (IDataReader dr = CreateReader(CreateCommand("Community_ImagesGetSectionImage", communityID, sectionID, imageID, width, height, isThumbnail)))
                if (dr.Read())
                    sectionImageInfo = new ImageData(dr);

            return sectionImageInfo;
        }

        public override ImageData GetCommunityImage(int communityID, string fileName)
        {
            ImageData communityImageInfo = null;

            using (IDataReader dr = CreateReader(CreateCommand("Community_ImagesGetCommunityImage", communityID, fileName)))
                if (dr.Read())
                    communityImageInfo = new ImageData(dr);

            return communityImageInfo;
        }

        public override DataSet GetCommunityImages(int communityID)
        {
            return ExecuteDataSet(CreateCommand("Community_ImagesGetCommunityImages", communityID));
        }

        public override void AddCommunityImage(int communityID, string fileName, string contentType, int imageType, byte[] imageData)
        {
            Execute(CreateCommand("Community_ImagesAddCommunityImage", communityID, fileName, contentType, imageType, imageData));
        }

        public override void DeleteCommunityImage(int communityID, string fileName)
        {
            Execute(CreateCommand("Community_ImagesDeleteCommunityImage", communityID, fileName));
        }

        public override void SaveSizedSectionImage(int communityID, int imageID, ImageData image)
        {
            Execute(CreateCommand("Community_ImagesSaveSizedSectionImage", communityID, imageID, image.Width, image.Height, image.IsThumbnail, image.Image));
        }
    }
}
