// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;

namespace DotCommunities.Framework.Providers
{
    /// <summary>
    /// Partial class for the implementation of the <see cref="FrameworkProvider"/> abstract class.
    /// </summary>
    public partial class SqlFrameworkProvider : FrameworkProvider
    {
        public override DataSet GetChildSections(int sectionID, string userRoles, int pageSize, int pageIndex)
        {
            return ExecuteDataSet(CreateCommand("Community_SectionsGetChildSections", sectionID, userRoles, pageSize, pageIndex));
        }

        public override int GetChildSectionCount(int sectionID, string userRoles)
        {
            return Execute(CreateCommand("Community_SectionsGetChildSectionTotalRecords", sectionID, userRoles));
        }

        public override DataSet GetAllSections(int communityID)
        {
            return ExecuteDataSet(CreateCommand("Community_SectionsGetAllSections", communityID));
        }

        public override DataSet GetAllEnabledSections(int communityID)
        {
            DataSet sections = ExecuteDataSet(CreateCommand("Community_SectionsGetAllEnabledSections", communityID));
            DataSet sectionSecurity = ExecuteDataSet(CreateCommand("Community_SectionsGetAllSectionRoles", communityID));
            DataSet sectionWebBoxes = ExecuteDataSet(CreateCommand("Community_SectionsGetAllSectionWebBoxes", communityID));
            DataSet sectionWebServiceBoxes = ExecuteDataSet(CreateCommand("Community_SectionsGetAllSectionWebServiceBoxes", communityID));

            sections.Tables[0].TableName = "Sections";
            sectionSecurity.Tables[0].TableName = "SectionSecurity";
            sectionWebBoxes.Tables[0].TableName = "SectionWebBoxes";
            sectionWebServiceBoxes.Tables[0].TableName = "SectionWebServiceBoxes";

            DataSet dstSections = new DataSet();

            dstSections.Merge(sections);
            dstSections.Merge(sectionSecurity);
            dstSections.Merge(sectionWebBoxes);
            dstSections.Merge(sectionWebServiceBoxes);

            return dstSections;
        }

        public override Section GetSection(int communityID, int sectionID)
        {
            DataSet sections = ExecuteDataSet(CreateCommand("Community_SectionsGetSection", communityID, sectionID));
            DataSet sectionSecurity = ExecuteDataSet(CreateCommand("Community_SectionsGetSectionRoles", communityID, sectionID));
            DataSet sectionWebBoxes = ExecuteDataSet(CreateCommand("Community_SectionsGetSectionWebBoxes", communityID, sectionID));
            DataSet sectionWebServiceBoxes = ExecuteDataSet(CreateCommand("Community_SectionsGetSectionWebServiceBoxes", communityID, sectionID));

            sections.Tables[0].TableName = "Sections";
            sectionSecurity.Tables[0].TableName = "SectionSecurity";
            sectionWebBoxes.Tables[0].TableName = "SectionWebBoxes";
            sectionWebServiceBoxes.Tables[0].TableName = "SectionWebServiceBoxes";

            DataSet dstSections = new DataSet();

            dstSections.Merge(sections);
            dstSections.Merge(sectionSecurity);
            dstSections.Merge(sectionWebBoxes);
            dstSections.Merge(sectionWebServiceBoxes);

            // If the section exists then return a Section object
            if (dstSections.Tables[0].Rows.Count > 0)
            {
                dstSections.Tables[0].Columns.Add("section_path");
                dstSections.Tables[0].Rows[0]["section_path"] = "";

                return new Section(
                    dstSections.Tables["Sections"].Rows[0], 
                    dstSections.Tables["SectionSecurity"].Select(), 
                    dstSections.Tables["SectionWebBoxes"].Select(), 
                    dstSections.Tables["SectionWebServiceBoxes"].Select());
            }

            // Does not exist so return null
            return null;
        }

        public override DataSet GetPossibleParents(int communityID, int sectionID)
        {
            return ExecuteDataSet(CreateCommand("Community_SectionsGetPossibleParents", communityID, sectionID));
        }

        public override int AddSection(
                                int communityID, 
                                int parentID, 
                                string name, 
                                string title, 
                                string menuTitle, 
                                string description, 
                                string pageTypeName, 
                                string pageSkin, 
                                string defaultPageSkin,
                                string pageLayout,
                                string pageStyle, 
                                string logo, 
                                string pageHeader, 
                                string pageFooter, 
                                string footer, 
                                string pageMetaKeys, 
                                string pageMetaDescription, 
                                bool enableCategories, 
                                bool enableComments, 
                                bool enableModeration, 
                                bool enableRatings, 
                                bool enableCommentRatings, 
                                bool enableNotifications, 
                                bool enableIndexing,
                                bool inheritTransformations, 
                                string transformations, 
                                bool areWebBoxesInherited, 
                                bool areWebServiceBoxesInherited, 
                                int webBoxDisplayMode, 
                                int webServiceBoxDisplayMode, 
                                string webServicePassword, 
                                int allowHtmlInput, 
                                int allowCommentHtmlInput, 
                                bool isSectionWebService, 
                                bool isSectionSyndicated, 
                                bool isSystem,
                                bool isEnabled, 
                                int recordsPerPage 
                                )
        {
            bool parentIDIsNull = parentID <= 0;
            return Execute(CreateCommand("Community_SectionsAddSection", 
                                communityID, 
                                parentIDIsNull ? null : (object)parentID, 
                                name, 
                                title, 
                                menuTitle, 
                                description, 
                                pageTypeName, 
                                pageSkin, 
                                defaultPageSkin,
                                pageLayout,
                                pageStyle, 
                                logo, 
                                pageHeader, 
                                pageFooter, 
                                footer, 
                                pageMetaKeys, 
                                pageMetaDescription, 
                                enableCategories, 
                                enableComments, 
                                enableModeration, 
                                enableRatings, 
                                enableCommentRatings, 
                                enableNotifications, 
                                enableIndexing,
                                inheritTransformations, 
                                transformations, 
                                areWebBoxesInherited, 
                                areWebServiceBoxesInherited, 
                                webBoxDisplayMode, 
                                webServiceBoxDisplayMode, 
                                webServicePassword, 
                                allowHtmlInput, 
                                allowCommentHtmlInput, 
                                isSectionWebService, 
                                isSectionSyndicated, 
                                isSystem,
                                isEnabled, 
                                recordsPerPage 
                                ));
        }

        public override void EditSection(
                                int communityID,
                                int sectionID,
                                int parentID,
                                string name,
                                string title,
                                string menuTitle,
                                string description,
                                string pageSkin,
                                string defaultPageSkin,
                                string pageLayout,
                                string pageStyle,
                                string logo,
                                string pageHeader,
                                string pageFooter,
                                string footer,
                                string pageMetaKeys,
                                string pageMetaDescription,
                                bool enableCategories,
                                bool enableComments,
                                bool enableModeration,
                                bool enableRatings,
                                bool enableCommentRatings,
                                bool enableNotifications,
                                bool enableIndexing,
                                bool inheritTransformations,
                                string transformations,
                                bool areWebBoxesInherited,
                                bool areWebServiceBoxesInherited,
                                int webBoxDisplayMode,
                                int webServiceBoxDisplayMode,
                                string webServicePassword,
                                int allowHtmlInput,
                                int allowCommentHtmlInput,
                                bool isSectionWebService,
                                bool isSectionSyndicated,
                                bool isEnabled,
                                int recordsPerPage
                                )
        {
            bool parentIDIsNull = parentID <= 0;
            Execute(CreateCommand("Community_SectionsEditSection",
                                communityID,
                                sectionID,
                                parentIDIsNull ? null : (object)parentID,
                                name,
                                title,
                                menuTitle,
                                description,
                                pageSkin,
                                defaultPageSkin,
                                pageLayout,
                                pageStyle,
                                logo,
                                pageHeader,
                                pageFooter,
                                footer,
                                pageMetaKeys,
                                pageMetaDescription,
                                enableCategories,
                                enableComments,
                                enableModeration,
                                enableRatings,
                                enableCommentRatings,
                                enableNotifications,
                                enableIndexing,
                                inheritTransformations,
                                transformations,
                                areWebBoxesInherited,
                                areWebServiceBoxesInherited,
                                webBoxDisplayMode,
                                webServiceBoxDisplayMode,
                                webServicePassword,
                                allowHtmlInput,
                                allowCommentHtmlInput,
                                isSectionWebService,
                                isSectionSyndicated,
                                isEnabled,
                                recordsPerPage
                                ));
        }

        public override void AddSectionRoles(int sectionID, int roleType, string[] roles)
        {
            // Delete the existing roles
            Execute(CreateCommand("Community_SectionsDeleteSectionRoles", sectionID, roleType));
            // Add the new roles
            foreach (string role in roles)
                Execute(CreateCommand("Community_SectionsAddSectionRole", sectionID, roleType, role));
        }

        public override void AddSectionWebBoxes(int sectionID, string[] webBoxes)
        {
            // Delete the existing web boxes
            Execute(CreateCommand("Community_SectionsDeleteSectionWebBoxes", sectionID));
            // Add the new web boxes
            foreach (string webBox in webBoxes)
                Execute(CreateCommand("Community_SectionsAddSectionWebBox", sectionID, webBox));            
        }

        public override void MoveSectionUp(int communityID, int sectionID)
        {
            Execute(CreateCommand("Community_SectionsMoveSectionUp", communityID, sectionID));
        }

        public override void MoveSectionDown(int communityID, int sectionID)
        {
            Execute(CreateCommand("Community_SectionsMoveSectionDown", communityID, sectionID));
        }

        public override void MakeSectionHome(int communityID, int sectionID)
        {
            Execute(CreateCommand("Community_SectionsMakeSectionHome", communityID, sectionID));
        }

        public override void DeleteSection(int communityID, int sectionID)
        {
            Execute(CreateCommand("Community_SectionsDeleteSection", communityID, sectionID));
        }
    }
}
