// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections.Generic;

namespace DotCommunities.Framework
{
    /// <summary>
    /// Represents the response from a syndicated feed.
    /// </summary>
    [Serializable]
    public class Syndication
    {
        string _title = String.Empty;
        string _link = String.Empty;
        string _description = String.Empty;
        string _copyright = String.Empty;
        string _imageTitle = String.Empty;
        string _imageUrl = String.Empty;
        string _imageLink = String.Empty;

        bool _syndicationFailedLastCall = false;

        DateTime _dateLastRefreshed;

        List<SyndicationItem> _items;

        /// <summary>
        /// Gets or sets the feed title.
        /// </summary>
        /// <value>The feed title.</value>
        public string Title 
        {
            get {return _title;}
            set {_title = value;}
        }

        /// <summary>
        /// Gets or sets the feed link.
        /// </summary>
        /// <value>The feed link.</value>
        public string Link 
        {
            get {return _link;}
            set {_link = value;}
        }

        /// <summary>
        /// Gets or sets the feed description.
        /// </summary>
        /// <value>The feed description.</value>
        public string Description 
        {
            get {return _description;}
            set {_description = value;}
        }

        /// <summary>
        /// Gets or sets the feed copyright.
        /// </summary>
        /// <value>The feed copyright.</value>
        public string Copyright 
        {
            get {return _copyright;}
            set {_copyright = value;}
        }

        /// <summary>
        /// Gets or sets the feed image title.
        /// </summary>
        /// <value>The feed image title.</value>
        public string ImageTitle {
            get {return _imageTitle;}
            set {_imageTitle = value;}
        }

        /// <summary>
        /// Gets or sets the feed image URL.
        /// </summary>
        /// <value>The feed image URL.</value>
        public string ImageUrl {
            get {return _imageUrl;}
            set {_imageUrl = value;}
        }
        
        /// <summary>
        /// Gets or sets the feed image link.
        /// </summary>
        /// <value>The feed image link.</value>
        public string ImageLink {
            get {return _imageLink;}
            set {_imageLink = value;}
        }

        /// <summary>
        /// Gets or sets a value indicating whether [syndication failed last call].
        /// </summary>
        /// <value>
        /// 	<c>true</c> if [syndication failed last call]; otherwise, <c>false</c>.
        /// </value>
        public bool SyndicationFailedLastCall
        {
            get { return _syndicationFailedLastCall; }
            set { _syndicationFailedLastCall = value; }
        }

        /// <summary>
        /// Gets or sets the date last refreshed.
        /// </summary>
        /// <value>The date last refreshed.</value>
        public DateTime DateLastRefreshed 
        {
            get {return _dateLastRefreshed;}
            set {_dateLastRefreshed = value;}
        }
        
        /// <summary>
        /// Gets or sets the items.
        /// </summary>
        /// <value>The items.</value>
        public List<SyndicationItem> Items 
        {
            set {_items = value;}
            get {return _items;}
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Syndication"/> class.
        /// </summary>
        public Syndication() {}
    }
}
