// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections.Generic;
using System.Text;

namespace DotCommunities.Framework
{
    /// <summary>
    /// Represents all the information about a particular feed subscription.
    /// </summary>
    [Serializable]
    public class SyndicationItem
    {
        int _contentPageID = -1;
        int _commentCount = 0;

        string _title = String.Empty;
        string _link = String.Empty;
        string _description = String.Empty;

        string[] _categories;

        bool _enableCategories = false;
        bool _enableComments = false;

        DateTime _dateCreated;

        /// <summary>
        /// Gets or sets the content page ID.
        /// </summary>
        /// <value>The Content Page ID.</value>
        public int ContentPageID
        {
            get { return _contentPageID; }
            set { _contentPageID = value; }
        }

        /// <summary>
        /// Gets or sets the number of comments for the item.
        /// </summary>
        /// <value>The Comment Count.</value>
        public int CommentCount
        {
            get { return _commentCount; }
            set { _commentCount = value; }
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
        public string Title 
        {
            get {return _title;}
            set {_title = value;}
        }

        /// <summary>
        /// Gets or sets the link.
        /// </summary>
        /// <value>The link.</value>
        public string Link 
        {
            get {return _link;}
            set {_link = value;}
        }

        /// <summary>
        /// Gets or sets the description.
        /// </summary>
        /// <value>The description.</value>
        public string Description 
        {
            get {return _description;}
            set {_description = value;}
        }

        /// <summary>
        /// Gets or sets the item categories.
        /// </summary>
        /// <value>The item categories.</value>
        public string[] Categories
        {
            get { return _categories; }
            set { _categories = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating if comments are enabled for
        /// the content section.
        /// </summary>
        /// <value>Are comments enabled?</value>
        public bool EnableComments
        {
            get { return _enableComments; }
            set { _enableComments = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating if categories (topics) are 
        /// enabled for the content section.
        /// </summary>
        /// <value>Are categories enabled?</value>
        public bool EnableCategories
        {
            get { return _enableCategories; }
            set { _enableCategories = value; }
        }

        /// <summary>
        /// Gets or sets the date the content was created.
        /// </summary>
        /// <value>The date the content was created.</value>
        public DateTime DateCreated
        {
            get { return _dateCreated; }
            set { _dateCreated = value; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SyndicationItem"/> class.
        /// </summary>
        public SyndicationItem() { }
    }
}
