// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;

using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Components;
using DotCommunities.Framework.Enums;

namespace DotCommunities.Framework.Tasks
{
    public class EmailQueue : CommunityTask
    {
        private readonly int FailureInterval = 15;
        private readonly int MaxRetries = 3;

        public override bool Execute()
        {
            bool result = true;

            try
            {
                DataSet communities = FrameworkManager.GetAllCommunities();

                foreach (DataRow dr in communities.Tables[0].Rows)
                {
                    Community community = new Community(dr);

                    if (community != null)
                    {
                        CommunitySettings settings = (CommunitySettings)community.GetCommunitySettings();

                        if (settings != null)
                            try
                            {
                                FrameworkManager.SendQueuedEmails(community.ID, settings, FailureInterval, MaxRetries);
                                LogManager.WriteDebug(EventCode.Tasks, LogManager.LogCategory.Tasks, "Task Complete", string.Format("EMail Queue Task (Community: {0}, {1}) Completed", community.ID, community.Name), false);
                            }
                            catch (Exception ex)
                            {
                                // Log the exception
                                LogManager.LogException(EventCode.Tasks, LogManager.LogCategory.Tasks, ex);
                                LogManager.WriteWarning(EventCode.Tasks, LogManager.LogCategory.Tasks, "Task Error", string.Format("EMail Queue Task Failed (Community: {0}, {1})", community.ID, community.Name));
                            }
                    }
                }
            }
            catch (Exception ex)
            {
                // Log the fatal task exception
                LogManager.LogException(EventCode.Tasks, LogManager.BuildCategories(LogManager.LogCategory.Tasks, LogManager.LogCategory.Exceptions), ex);
            }

            return result;
        }
    }
}
