// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Xml.Serialization;

namespace DotCommunities.Framework
{
    /// <summary>
    /// Holds the time zone data, deserialised from the XML file.
    /// </summary>
    [Serializable]
    [XmlRoot("TimeZones")]
    public class TimeZoneData
    { 
        private Zone[] items;

        /// <summary>
        /// Gets or sets the list of timezones.
        /// </summary>
        [XmlArrayItem("Zone", typeof(Zone))]
        public Zone[] Items
        {
            get { return items; }
            set { items = value; }
        }
    }

    /// <summary>
    /// Holds information about a particular time zone.
    /// </summary>
    [Serializable]
    public class Zone
    {
        private string id;
        private double offset;
        private bool isUserZone;
        private string description;

        /// <summary>
        /// Gets or sets the time zone ID (e.g. GMT).
        /// </summary>
        [XmlAttribute("id")]
        public string ID
        {
            get { return id; }
            set { id = value; }
        }

        /// <summary>
        /// Gets or sets the time zone offset.
        /// </summary>
        [XmlAttribute("offset")]
        public double Offset
        {
            get { return offset; }
            set { offset = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating if the 
        /// time zone is also a user selectable time zone.
        /// </summary>
        [XmlAttribute("isUserZone")]
        public bool IsUserZone
        {
            get { return isUserZone; }
            set { isUserZone = value; }
        }

        /// <summary>
        /// Gets or sets the description of the time zone.
        /// </summary>
        [XmlText]
        public string Description
        {
            get { return description; }
            set { description = value; }
        }
    }
}
