// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections.Generic;
using System.Text;

using DotCommunities.Framework.Managers;
using DotCommunities.Modules.Providers;
using DotCommunities.Framework.Components;

namespace DotCommunities.Modules.Managers
{
    /// <summary>
    /// The <see cref="ModuleManager"/> configures the <see cref="ModuleProvider"/>.
    /// </summary>
    public partial class ModuleManager : FrameworkManagerBase
    {
        private static ModuleManager manager;
        private static ModuleProvider provider;

        /// <summary>
        /// Loads the providers from the module configuration section.
        /// </summary>
        static ModuleManager()
        {
            manager = new ModuleManager();
            manager.LoadProviders("moduleProviders");

            // Set the events to refresh the content when changed
            FrameworkManager.ContentSortOrderChanged += new EventHandler(Article_SortOrderChanged);
        }

        /// <summary>
        /// Gets or sets the provider, overriden to set the provider as a <see cref="ModuleProvider"/>.
        /// </summary>
        protected override CommunityProviderBase CommunityProvider
        {
            get { return (CommunityProviderBase)provider; }
            set { provider = (ModuleProvider)value; }
        }

        /// <summary>
        /// Gets the default provider as a <see cref="ModuleProvider"/> object.
        /// </summary>
        protected static ModuleProvider Provider
        {
            get { return provider; }
        }
    }
}
