// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Collections.Generic;
using System.Text;

using DotCommunities.Framework;

namespace DotCommunities.Modules
{
    /// <summary>
    /// Represents all information about a particular photo.
    /// </summary>
    public class Photo : CommunityContent
    {
        int _imageID;
        string _imageName;
        string _fullDescription;

        /// <summary>
        /// Initializes a new instance of the <see cref="Photo"/> class.
        /// </summary>
        /// <param name="dr">The <see cref="IDataReader"/> containing the content information.</param>
        public Photo(IDataReader dr)
            : base(dr)
        {
            // Populate required fields
            _imageID = (int)dr["Image_ID"];
            _imageName = (string)dr["Image_FileName"];

            // Populate optional fields
            if (dr["Photo_FullDescription"] != DBNull.Value)
                _fullDescription = (string)dr["Photo_FullDescription"];
        }

        /// <summary>
        /// Gets or sets the image ID.
        /// </summary>
        /// <value>The image ID.</value>
        public int ImageID
        {
            get { return _imageID; }
            set { _imageID = value; }
        }

        /// <summary>
        /// Gets or sets the name of the image.
        /// </summary>
        /// <value>The name of the image.</value>
        public string ImageName
        {
            get { return _imageName; }
            set { _imageName = value; }
        }

        /// <summary>
        /// Gets or sets the full description.
        /// </summary>
        /// <value>The full description.</value>
        public string FullDescription
        {
            get { return _fullDescription; }
            set { _fullDescription = value; }
        }
    }
}
