// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Collections.Generic;

namespace DotCommunities.Modules.Providers
{
    /// <summary>
    /// Partial class for the implementation of the <see cref="ModuleProvider"/> abstract class.
    /// </summary>
    public partial class SqlModuleProvider : ModuleProvider
    {
        public override Article GetArticle(int communityID, int contentPageID, string userName)
        {
            Article articleInfo = null;

            using (IDataReader dr = CreateReader(CreateCommand("Community_ArticlesGetArticle", communityID, contentPageID, userName)))
                if (dr.Read())
                    articleInfo = new Article(dr);

            return articleInfo;
        }

        public override List<object> GetArticles(int communityID, int sectionID, string userName, int pageSize, int pageIndex, string sortOrder)
        {
            List<object> articles = new List<object>();

            using (IDataReader dr = CreateReader(CreateCommand("Community_ArticlesGetArticles", communityID, sectionID, userName, pageSize, pageIndex, sortOrder)))
                while (dr.Read())
                    articles.Add(new Article(dr));

            return articles;
        }

        public override int AddArticle(int communityID, int sectionID, string userName, string categories, string title, string description, string metaDescription, string metaKeys, int moderationStatus, string body)
        {
            return Execute(CreateCommand("Community_ArticlesAddArticle", communityID, sectionID, userName, categories, title, description, metaDescription, metaKeys, moderationStatus, body));
        }

        public override void EditArticle(int communityID, int contentPageID, string userName, string categories, string title, string description, string metaDescription, string metaKeys, string body)
        {
            Execute(CreateCommand("Community_ArticlesEditArticle", communityID, contentPageID, userName, categories, title, description, metaDescription, metaKeys, body));
        }
    }
}
