// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System.Configuration;

using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;

namespace DotCommunities.Blocks.Tasks.Configuration
{
    /// <summary>
    /// Configuration data defining TaskManagerData. Defines the information needed to properly configure
    /// a TaskManager instance.
    /// </summary>    	
    public class TaskManagerData : NamedConfigurationElement
	{
        private const string tasksProperty = "tasks";
        private const string minutesProperty = "minutes";

		/// <summary>
		/// Initialize a new instance of the <see cref="TaskManagerData"/> class.
		/// </summary>
		public TaskManagerData()
		{
		}

		/// <summary>
		/// Initialize a new instance of the <see cref="TaskManagerData"/> class.
		/// </summary>
		/// <param name="name">
		/// The name of the <see cref="TaskManagerData"/>.
		/// </param>
        /// <param name="minutes">
		/// Frequency in minutes of the task queue polling cycle
		/// </param>
        public TaskManagerData(string name, int minutes)
			: base(name)
		{
			this.Minutes = minutes;
		}

		/// <summary>
		/// Frequency in seconds of expiration polling cycle
		/// </summary>
        [ConfigurationProperty(minutesProperty, IsRequired = true)]
		public int Minutes
		{
            get { return (int)base[minutesProperty]; }
            set { base[minutesProperty] = value; }
		}

        /// <summary>
        /// Gets the collection of defined <see cref="Task"/> objects.
        /// </summary>
        /// <value>
        /// The collection of defined <see cref="Task"/> objects.
        /// </value>
        [ConfigurationProperty(tasksProperty, IsRequired = true)]
        public NamedElementCollection<TaskData> Tasks
        {
            get { return (NamedElementCollection<TaskData>)base[tasksProperty]; }
        }
    }
}
