// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System.Configuration;

using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;

namespace DotCommunities.Blocks.Tasks.Configuration
{
    /// <summary>
    /// This type supports the Enterprise Library infrastructure and is not intended to be used directly from your code.
    /// Resolves default names for task managers.
    /// </summary>
    public class TaskManagerDataRetriever : IConfigurationNameMapper
    {
        /// <summary>
        /// This method supports the Enterprise Library infrastructure and is not intended to be used directly from your code.
        /// Returns the default task manager name from the configuration in the <paramref name="configSource"/>, if the
        /// value for <paramref name="name"/> is <see langword="null"/> (<b>Nothing</b> in Visual Basic).
        /// </summary>
        /// <param name="name">The current name.</param>
        /// <param name="configurationSource">The source for configuration information.</param>
        /// <returns>The default task manager name if <paramref name="name"/> is <see langword="null"/> (<b>Nothing</b> in Visual Basic),
        /// otherwise the original value for <b>name</b>.</returns>
        public string MapName(string name, IConfigurationSource configurationSource)
        {
            if (name == null)
            {
                TaskConfigurationView view = new TaskConfigurationView(configurationSource);
                return view.DefaultTaskManager;
            }

            return name;
        }
    }
}
