// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework;
using DotCommunities.Framework.Components;
using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Collections;

public partial class Admin_Categories_CategoryGeneral : System.Web.UI.UserControl
{
    public int CategoryID
    {
        get { return (int)ViewState["CategoryID"]; }
        set { ViewState["CategoryID"] = value; }
    }

    public int SectionID
    {
        get { return int.Parse(ddlSections.SelectedValue); }
    }

    public string Name
    {
        get { return txtCategoryName.Text; }
    }

    public string Description
    {
        get { return txtCategoryDescription.Text; }
    }

    public HttpPostedFile CategoryImage
    {
        get { return txtCategoryImage.PostedFile; }
    }

    public string ExistingImageName
    {
        get 
        { 
            if (ViewState["ExistingImageName"] != null)
                return ViewState["ExistingImageName"].ToString();
            return null;
        }
        set { ViewState["ExistingImageName"] = value; }
    }

    public bool RemoveImage
    {
        get { return chkRemoveImage.Checked; }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            // Get CategoryID
            int categoryID = 0;
            if (int.TryParse(Request.QueryString["ID"], out categoryID))
                CategoryID = categoryID;

            // Setup UI
            ddlSections.Items.Add(new ListItem("(None)", "0"));

            SectionCollection sections = FrameworkManager.GetAllEnabledSections();
            foreach (Section section in sections.Values)
                if (!section.IsSystem)
                    ddlSections.Items.Add(new ListItem(section.Name, section.SectionID.ToString()));

            if (categoryID > 0)
            {
                // Retrieve Category Info
                Category objCategoryInfo = FrameworkManager.GetCategory(categoryID);

                // Assign initial values
                txtCategoryName.Text = objCategoryInfo.Name;
                txtCategoryDescription.Text = objCategoryInfo.Description;

                ddlSections.SelectedValue = objCategoryInfo.SectionID.ToString();

                if (!string.IsNullOrEmpty(objCategoryInfo.ImagePath))
                {
                    pnlCategoryImage.Visible = true;
                    ExistingImageName = objCategoryInfo.ImagePath;
                    imgCategoryPreview.ImageUrl = ResolveUrl("~/" + CommunityContext.CalculateGenericHandlersPath(objCategoryInfo.ImagePath));
                }
            }
        }
    }
}
