// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework;
using DotCommunities.Framework.Controls;
using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Enums;

public partial class Admin_Communities_EditCommunity : AdministrationPage
{
    protected override string PageTitle
    {
        get { return "Edit Community"; }
    }

    protected override string PageSubTitle
    {
        get { return "Use this page to configure a community website."; }
    }

    protected override string[] MenuItems
    {
        get { return new string[] { "Home", "Community List" }; }
    }

    protected override string[] MenuLinks
    {
        get { return new string[] { "Main/Default.aspx", "Communities/Default.aspx" }; }
    }

    protected override string[] ActionItems
    {
        get { return new string[] { "Add Community" }; }
    }

    protected override string[] ActionLinks
    {
        get { return new string[] { "Communities/AddCommunity.aspx" }; }
    }

    protected void Page_Init(object sender, System.EventArgs e)
    {
        // Redirect the user if they do not have access
        if (!Roles.IsUserInRole(CommunityRole.System.ToString()))
        {
            string msg = HttpUtility.UrlEncode("Only System Administrators are allowed to edit communities");
            Response.Redirect("../Main/Default.aspx?Message=Warning&MessageText=" + msg);
        }
    }

    protected void Page_Load(object sender, System.EventArgs e)
    {
        // Load Community Info
        if (!Page.IsPostBack)
        {
            int communityID = 0;
            if (Int32.TryParse(Request.QueryString["id"], out communityID))
                ctlGeneral.Community = FrameworkManager.GetCommunity(communityID);
        }
    }

    protected void btnAdd_Click(object sender, System.EventArgs e)
    {
        if (Page.IsValid)
        {
            int communityID = 0;
            if (Int32.TryParse(Request.QueryString["id"], out communityID))
                FrameworkManager.EditCommunity
                (
                    communityID,
                    ctlGeneral.CommunityName,
                    ctlGeneral.DomainName,
                    ctlGeneral.Domain,
                    ctlGeneral.SubDomain,
                    ctlGeneral.ApplicationPath,
                    ctlGeneral.DatabaseQuota,
                    ctlGeneral.IsEnabled
                );

            Response.Redirect("Default.aspx");
        }
    }
}
