// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework;

public partial class Admin_Controls_GridPageSize : System.Web.UI.UserControl
{
    private readonly string DefaultPageSizes = "10|25";

    private GridView gridViewControl;

    private int PageSize
    {
        get
        {
            if (ViewState["PageSize"] != null)
                return (int)ViewState["PageSize"];
            return 10;
        }
        set { ViewState["PageSize"] = value; }
    }

    public string PageSizes
    {
        get 
        {
            if (ViewState["PageSizes"] != null)
                return ViewState["PageSizes"].ToString();
            return string.Empty;
        }
        set { ViewState["PageSizes"] = value; }
    }

    public string GridViewID
    {
        get
        {
            if (ViewState["GridViewID"] != null)
                return ViewState["GridViewID"].ToString();
            return string.Empty;
        }
        set { ViewState["GridViewID"] = value; }
    }

    public bool AllowAll
    {
        get
        {
            if (ViewState["AllowAll"] != null)
                return (bool)ViewState["AllowAll"];
            return true;
        }
        set { ViewState["AllowAll"] = value; }
    }

    protected void Page_Init(object sender, EventArgs e)
    {
        if (string.IsNullOrEmpty(PageSizes))
            PageSizes = DefaultPageSizes;
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!string.IsNullOrEmpty(GridViewID))
            gridViewControl = (GridView)Parent.FindControl(GridViewID);

        if (!Page.IsPostBack)
            DataBindPageSizes(true);
    }

    protected void PageSizeRepeater_ItemDataBound(object sender, RepeaterItemEventArgs e)
    {
        if (e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem)
        {
            LinkButton pageSizeButton = null;

            int pageSize = 0;
            int.TryParse(e.Item.DataItem.ToString(), out pageSize);

            pageSizeButton = (LinkButton)e.Item.FindControl("PageSizeButton");

            if (pageSizeButton != null && PageSize == pageSize)
                pageSizeButton.Enabled = false;
        }
    }

    protected void PageSizeButton_OnCommand(object sender, CommandEventArgs e)
    {
        if (e.CommandName == "SetPageSize" && gridViewControl != null)
        {
            int pageSize = 0;
            if (int.TryParse(e.CommandArgument.ToString(), out pageSize))
                SetPageSize(pageSize);
            else
                SetPageSize(0);

            DataBindPageSizes();
        }
    }

    private void DataBindPageSizes()
    {
        DataBindPageSizes(false);
    }

    private void DataBindPageSizes(bool bindToFirstSize)
    {
        int pageSize = 0;
        int profilePageSize = CommunityUser.GetProfile(Context.User.Identity.Name).DefaultGridPageSize;

        List<string> pages = new List<string>(PageSizes.Split('|'));

        if (profilePageSize > 0)
        {
            bool pageSizeSet = false;
            int lastPageSize = 0;

            for (int i = 0; i < pages.Count; i++)
            {
                if (int.TryParse(pages[i], out pageSize))
                    if (pageSize >= profilePageSize && lastPageSize <= profilePageSize)
                    {
                        SetPageSize(pageSize);
                        pageSizeSet = true;
                        break;
                    }

                lastPageSize = pageSize;
            }

            // Check that the page size has been set
            if ((!pageSizeSet) && int.TryParse(pages[0], out pageSize))
                SetPageSize(pageSize);
        }
        else if (bindToFirstSize)
        {
            if (int.TryParse(pages[0], out pageSize))
                SetPageSize(pageSize);
        }

        if (AllowAll)
            pages.Add("All");

        PageSizeRepeater.DataSource = pages;
        PageSizeRepeater.DataBind();
    }

    private void SetPageSize(int pageSize)
    {
        if (gridViewControl != null)
        {
            // Persist the current page size in the profile
            if (pageSize != PageSize)
            {
                CommunityProfile profile = CommunityUser.GetProfile(Context.User.Identity.Name);
                // Set the new page size
                profile.DefaultGridPageSize = pageSize;
                // Save the modified profile
                profile.Save();
            }

            if (pageSize > 0)
            {
                gridViewControl.AllowPaging = true;
                gridViewControl.PageSize = pageSize;

                PageSize = pageSize;
            }
            else
            {
                gridViewControl.AllowPaging = false;
                gridViewControl.PageSize = PageSize;

                PageSize = 0;
            }
        }
    }
}
