// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text;

using DotCommunities.Framework;
using DotCommunities.Framework.Enums;
using DotCommunities.Framework.Managers;

public partial class Admin_Controls_Headlines : System.Web.UI.UserControl
{
    private ServiceResponse responseInfo = null;

    protected readonly string ResponseUrl = "http://www.caskdotnet.com/CP/News/RssHandler.ashx";

    protected string Title
    {
        get 
        {
            string title = string.Empty;
            if (responseInfo != null)
                title = responseInfo.ServiceTitle;
            return title; 
        }
    }

    protected string Description
    {
        get
        {
            string description = string.Empty;
            if (responseInfo != null)
                description = responseInfo.ServiceDescription;
            return description;
        }
    }

    protected string Link
    {
        get
        {
            string link = string.Empty;
            if (responseInfo != null)
                link = responseInfo.ServiceLink;
            return link;
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        Service serviceInfo = new Service();
        serviceInfo.Url = ResponseUrl;
        serviceInfo.ServiceType = ServiceType.RSS;
        serviceInfo.RefreshRate = 24 * 60;
        serviceInfo.MaximumItems = 10;
        serviceInfo.Name = "DotCommunities_SiteHeadlines";
        serviceInfo.ID = -1;

        responseInfo = FrameworkManager.GetServiceResponse(serviceInfo.Name, ref serviceInfo);

        if (responseInfo != null && responseInfo.Items != null)
        {
            StringBuilder sb = new StringBuilder();

            foreach (ServiceResponseItem item in responseInfo.Items)
            {
                sb.Append("<div class=\"newsline\">");
                sb.Append(string.Format("<a href=\"{0}\" target=\"_blank\">{1}</a>", item.Link, item.Title));
                sb.Append(string.Format("<p>{0}</p>", item.Description));
                sb.Append("</div>");
            }

            HeadlineItems.Text = sb.ToString();
        }

        if (responseInfo != null)
        {
            HtmlLink rssDetectorLink = new HtmlLink();

            rssDetectorLink.Attributes.Add("type", "application/rss+xml");
            rssDetectorLink.Attributes.Add("rel", "alternate");
            rssDetectorLink.Attributes.Add("title", "RSS 2.0 Feed: " + responseInfo.ServiceTitle);

            rssDetectorLink.Href = ResponseUrl;

            Page.Header.Controls.Add(rssDetectorLink);
        }
        else
        {
            headlines.Visible = false;
            nonews.Visible = true;
        }
    }
}
