// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Drawing;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework.Components;
using DotCommunities.Framework.Enums;

public partial class Admin_Controls_SiteStatus : System.Web.UI.UserControl
{
    /// <summary>
    /// Fires when the status of the community changes.
    /// </summary>
    public event EventHandler StatusChanged;

    public CommunityStatus Status
    {
        get { return CommunityContext.CommunityStatus; }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        // Always update the UI when loading the control
        UpdateUI();
    }

    private void UpdateUI()
    {
        switch (CommunityContext.CommunityStatus)
        {
            case CommunityStatus.Offline:
                StatusLabel.Text = CommunityStatus.Offline.ToString();
                StatusLabel.ForeColor = Color.Red;
                CurrentStatus.SelectedValue = ((int)CommunityStatus.Offline).ToString();
                break;
            default:
                StatusLabel.Text = CommunityStatus.Available.ToString();
                StatusLabel.ForeColor = Color.Green;
                CurrentStatus.SelectedValue = ((int)CommunityStatus.Available).ToString();
                break;
        }
    }

    private void ToggleStatus()
    {
        // Swap the status from available to offline
        switch (CommunityContext.CommunityStatus)
        {
            case CommunityStatus.Offline:
                CommunityContext.CommunityStatus = CommunityStatus.Available;
                break;
            default:
                CommunityContext.CommunityStatus = CommunityStatus.Offline;
                break;
        }
        // Update the UI after the switch
        UpdateUI();
    }

    protected void CurrentStatus_SelectedIndexChanged(object sender, EventArgs e)
    {
        // Update the status
        ToggleStatus();
        // Fire the status changed handler
        if (StatusChanged != null)
            StatusChanged(this, EventArgs.Empty);
    }
}
