// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework.Controls;
using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Enums;

/// <summary>
/// Summary description for Admin_Sections_Default.
/// </summary>
public partial class Admin_Sections_Default : AdministrationPage
{
    protected override string PageTitle
    {
        get { return "Manage Sections"; }
    }

    protected override string PageSubTitle
    {
        get { return "Manage the sections and structure of the site."; }
    }

    protected override string[] MenuItems
    {
        get { return new string[] { "Home" }; }
    }

    protected override string[] MenuLinks
    {
        get { return new string[] { "Main/Default.aspx" }; }
    }

    protected override string[] ActionItems
    {
        get { return new string[] { "Add New Section" }; }
    }

    protected override string[] ActionLinks
    {
        get { return new string[] { "Sections/AddSection.aspx" }; }
    }

    public string GetPageTypeName(string pageType)
    {
        return ContentTypesManager.GetModuleSections()[pageType].Title;
    }

    //*******************************************************
    //
    // When binding sections to the DataGrid, don't
    // show delete link for sections with children
    // and don't show order arrows for system sections.
    //
    //*******************************************************

    protected void SectionsGrid_RowDataBound(Object s, GridViewRowEventArgs e)
    {
        ImageButton btnDelete;
        ImageButton btnHome;
        ImageButton btnSortUp;
        ImageButton btnSortDown;

        // Skip if no data row
        if (e.Row.RowType == DataControlRowType.DataRow)
        {
            DataRowView drow = (DataRowView)e.Row.DataItem;

            int childCount = (int)drow["ChildCount"];
            bool isRoot = drow["Section_ParentID"] == DBNull.Value;
            bool isSystem = (bool)drow["Section_IsSystem"];
            bool adminUser = User.IsInRole(CommunityRole.Administrators.ToString());

            btnDelete = (ImageButton)e.Row.FindControl("btnDelete");

            // Don't display delete link for sections with children or system sections
            if (childCount > 0 || isRoot || isSystem)
            {
                // Remove the delete button
                if (btnDelete != null)
                    btnDelete.Visible = false;
            }
            else
            {
                // Add confirmation to delete button
                string sectionName = drow["Section_Name"].ToString();
                if (btnDelete != null)
                {
                    if (adminUser)
                    {
                        btnDelete.CommandArgument = e.Row.RowIndex.ToString();
                        btnDelete.Attributes.Add("onclick", String.Format("return confirm('Are you sure you want to delete the \"{0}\" section?')", sectionName));
                    }
                    else
                    {
                        btnDelete.Enabled = false;
                        btnDelete.ToolTip = "Delete (Community Administrators Only)";
                    }
                }
            }

            // Show the correct home page image
            btnHome = (ImageButton)e.Row.FindControl("btnHome");
            if (btnHome != null)
            {
                if (drow["Section_ParentID"] == DBNull.Value)
                {
                    btnHome.ImageUrl = "../Images/Home.gif";
                    btnHome.Enabled = false;
                    btnHome.ToolTip = "This section is the home page";
                }
                else
                {
                    btnHome.ImageUrl = "../Images/Home_Ghost.gif";

                    if ((!isSystem) && adminUser)
                    {
                        btnHome.CommandArgument = e.Row.RowIndex.ToString();
                        btnHome.ToolTip = "Set this section as the home page";
                    }
                    else if (isSystem)
                    {
                        btnHome.Enabled = false;
                        btnHome.ToolTip = "System sections cannot be set as the home page";
                    }
                    else
                    {
                        btnHome.Enabled = false;
                        btnHome.ToolTip = "Set Home Page (Community Administrators Only)";
                    }
                }
            }

            btnSortUp = (ImageButton)e.Row.FindControl("btnSortUp");
            btnSortDown = (ImageButton)e.Row.FindControl("btnSortDown");

            if (btnSortUp != null)
                if (adminUser)
                    btnSortUp.CommandArgument = e.Row.RowIndex.ToString();
                else
                {
                    btnSortUp.Enabled = false;
                    btnSortUp.ToolTip = "Move Section Up (Community Administrators Only)";
                }

            if (btnSortDown != null)
                if (adminUser)
                    btnSortDown.CommandArgument = e.Row.RowIndex.ToString();
                else
                {
                    btnSortDown.Enabled = false;
                    btnSortDown.ToolTip = "Move Section Down (Community Administrators Only)";
                }

            // Remove sort buttons for system sections
            if (isRoot || isSystem)
            {
                if (btnSortUp != null)
                    btnSortUp.Visible = false;

                if (btnSortDown != null)
                    btnSortDown.Visible = false;
            }
        }        
    }

    protected void SectionsGrid_RowCommand(Object s, GridViewCommandEventArgs e)
    {
        int index = -1;

        if (User.IsInRole(CommunityRole.Administrators.ToString()) && int.TryParse(e.CommandArgument.ToString(), out index))
        {
            switch (e.CommandName)
            {
                case "Delete":
                    FrameworkManager.DeleteSection((int)SectionsGrid.DataKeys[index].Value);
                    break;
                case "Up":
                    FrameworkManager.MoveSectionUp((int)SectionsGrid.DataKeys[index].Value);
                    break;
                case "Down":
                    FrameworkManager.MoveSectionDown((int)SectionsGrid.DataKeys[index].Value);
                    break;
                case "Home":
                    FrameworkManager.MakeSectionHome((int)SectionsGrid.DataKeys[index].Value);
                    break;
            }

            SectionsGrid.DataBind();
        }
    }
}
