// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework;
using DotCommunities.Framework.Controls;
using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Enums;
using DotCommunities.Framework.Components;

/// <summary>
/// Summary description for EditSection.
/// </summary>
public partial class Admin_Sections_EditSection : AdministrationPage
{
    protected override string PageTitle
    {
        get { return "Edit Section"; }
    }

    protected override string PageSubTitle
    {
        get { return "Use this page to edit an existing section."; }
    }

    protected override string[] MenuItems
    {
        get { return new string[] { "Home", "Section List" }; }
    }

    protected override string[] MenuLinks
    {
        get { return new string[] { "Main/Default.aspx", "Sections/Default.aspx" }; }
    }

    protected override string[] ActionItems
    {
        get { return new string[] { "Add New Section" }; }
    }

    protected override string[] ActionLinks
    {
        get { return new string[] { "Sections/AddSection.aspx" }; }
    }

    public int SectionID
    {
        get { return (int)ViewState["SectionID"]; }
        set { ViewState["SectionID"] = value; }
    }

    protected void Page_Load(object sender, System.EventArgs e)
    {
        // Hide quota stats if not over quota
        if (valQuota.IsValid)
            valQuota.Visible = false;

        if (!IsPostBack)
        {
            // Assign section ID
            SectionID = Int32.Parse(Request.QueryString["id"]);

            // Get the Section information
            Section objSectionInfo = FrameworkManager.GetSection(SectionID);

            // Assign the Section values
            ctlGeneral.Section = objSectionInfo;
            ctlAppearance.Section = objSectionInfo;
            ctlWebBoxes.Section = objSectionInfo;
            ctlSecurity.Section = objSectionInfo;
            ctlWebServices.Section = objSectionInfo;
            ctlAdvanced.Section = objSectionInfo;

            // Initialize roles
            ArrayList colAllRoles = new ArrayList(CommunityUser.AllRoles);
            ctlSecurity.AllRoles = colAllRoles;
            ctlAdvanced.AllRoles = colAllRoles;
        }

        btnUpdateSection.Enabled = User.IsInRole(CommunityRole.Administrators.ToString());
        lblAdminOnly.Visible = !btnUpdateSection.Enabled;
    }

    private void Return(string messageType, string messageText)
    {
        Response.Redirect(string.Format("Default.aspx?Message={0}&MessageText={1}", messageType, HttpUtility.UrlEncode(messageText)));
    }

    protected void UpdateSection(Object s, EventArgs e)
    {
        if (IsValid)
        {
            try
            {
                FrameworkManager.EditSection
                (
                    SectionID,
                    ctlGeneral.ParentSectionID,
                    ctlGeneral.Name,
                    ctlGeneral.Title,
                    ctlGeneral.MenuTitle,
                    ctlGeneral.Description,
                    ctlAppearance.PageSkin,
                    ctlAppearance.FailSkin,
                    ctlAppearance.PageLayout,
                    ctlAppearance.PageStyle,
                    ctlAppearance.Logo,
                    ctlAppearance.PageHeader,
                    ctlAppearance.PageFooter,
                    ctlAppearance.Footer,
                    ctlAppearance.PageMetaKeys,
                    ctlAppearance.PageMetaDescription,
                    ctlAdvanced.EnableCategories,
                    ctlAdvanced.EnableComments,
                    ctlAdvanced.EnableModeration,
                    ctlAdvanced.EnableRatings,
                    ctlAdvanced.EnableCommentRatings,
                    ctlAdvanced.EnableNotifications,
                    true,
                    ctlAppearance.InheritTransformations,
                    ctlAppearance.Transformations,
                    ctlWebBoxes.InheritWebBoxes,
                    ctlWebBoxes.InheritWebServiceBoxes,
                    ctlWebBoxes.WebBoxDisplayMode,
                    ctlWebBoxes.WebServiceBoxDisplayMode,
                    ctlWebServices.WebServicePassword,
                    ctlAdvanced.AllowHtmlInput,
                    ctlAdvanced.AllowCommentHtmlInput,
                    ctlWebServices.IsSectionWebService,
                    true,
                    ctlGeneral.IsEnabled,
                    ctlAdvanced.RecordsPerPage
                );

                // Update View Roles
                if (ctlSecurity.ViewRolesChanged)
                    FrameworkManager.AddSectionRoles(SectionID, RoleType.ViewRole, ctlSecurity.ViewRoles);

                // Update Add Roles
                if (ctlSecurity.AddRolesChanged)
                    FrameworkManager.AddSectionRoles(SectionID, RoleType.AddRole, ctlSecurity.AddRoles);

                // Update Edit Roles
                if (ctlSecurity.EditRolesChanged)
                    FrameworkManager.AddSectionRoles(SectionID, RoleType.EditRole, ctlSecurity.EditRoles);

                // Update Delete Roles
                if (ctlSecurity.DeleteRolesChanged)
                    FrameworkManager.AddSectionRoles(SectionID, RoleType.DeleteRole, ctlSecurity.DeleteRoles);

                // Update Comment Roles
                if (ctlAdvanced.CommentRolesChanged)
                    FrameworkManager.AddSectionRoles(SectionID, RoleType.CommentRole, ctlAdvanced.CommentRoles);

                // Update Moderate Roles
                if (ctlAdvanced.ModerateRolesChanged)
                    FrameworkManager.AddSectionRoles(SectionID, RoleType.ModerateRole, ctlAdvanced.ModerateRoles);

                // Update Rate Roles
                if (ctlAdvanced.RateRolesChanged)
                    FrameworkManager.AddSectionRoles(SectionID, RoleType.RateRole, ctlAdvanced.RateRoles);

                // Update Web Boxes
                if (ctlWebBoxes.WebBoxesChanged)
                    FrameworkManager.AddSectionWebBoxes(SectionID, ctlWebBoxes.WebBoxes);

                //// Update Web Service Boxes
                //if (ctlWebBoxes.WebServiceBoxesChanged)
                //    SectionUtility.AddSectionWebServiceBoxes(SectionID, ctlWebBoxes.WebServiceBoxes);

                //// Update Service Subscriptions
                //if (ctlWebServices.ServiceSubscriptionsChanged)
                //    SectionUtility.AddSectionServiceSubscriptions(SectionID, ctlWebServices.ServiceSubscriptions);
            }
            catch
            {
                ShowError("Could not update the section.");
            }

            // Redirect to EditSections
            Return("Information", "Section updated sucsessfully.");
        }
    }
}
