// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;

using DotCommunities.Framework;
using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Components;

/// <summary>
///	Summary description for SectionAppearance.
/// </summary>
public partial class Admin_Sections_SectionAppearance : System.Web.UI.UserControl
{
    public Section Section;

    public string PageSkin
    {
        get { return dropThemes.SelectedItem.Value; }
    }

    public string FailSkin
    {
        get { return dropFailTheme.SelectedItem.Value; }
    }

    public string PageStyle
    {
        get { return dropStyles.SelectedItem.Value; }
    }

    public string PageLayout
    {
        get 
        {
            if (dropLayouts.SelectedItem.Value == "(None)")
                return string.Empty;
            return dropLayouts.SelectedItem.Value; 
        }
    }

    public HttpPostedFile Logo
    {
        get { return txtLogo.PostedFile; }
    }

    public string PageHeader
    {
        get { return txtPageHeader.Text; }
    }

    public string PageFooter
    {
        get { return txtPageFooter.Text; }
    }

    public string Footer
    {
        get { return txtFooter.Text; }
    }

    public string PageMetaDescription
    {
        get { return txtPageMetaDesc.Text; }
    }

    public string PageMetaKeys
    {
        get { return txtPageMetaKeys.Text; }
    }

    public bool InheritTransformations
    {
        get
        {
            if (Section != null && Section.ParentID == -1)
                return false;
            else
                return rdlInheritTransformations.Checked;
        }
    }

    public string Transformations
    {
        get { return txtTransformations.Text; }
    }

    protected void Page_Load(object sender, System.EventArgs e)
    {
        if (!IsPostBack)
        {
            // Initialize Themes
            dropThemes.DataSource = ThemeManager.GetThemes().Values;
            dropThemes.DataTextField = "ThemeName";
            dropThemes.DataValueField = "ThemeName";
            dropThemes.DataBind();

            dropFailTheme.DataSource = ThemeManager.GetThemes().Values;
            dropFailTheme.DataTextField = "ThemeName";
            dropFailTheme.DataValueField = "ThemeName";
            dropFailTheme.DataBind();

            // Initialize Styles
            dropStyles.DataSource = ThemeManager.GetStyles().Values;
            dropStyles.DataTextField = "StyleName";
            dropStyles.DataValueField = "StyleName";
            dropStyles.DataBind();

            // Initialize Layouts
            if (CommunityContext.WebPartsEnabled)
            {
                List<string> layouts = LayoutManager.GetAllLayouts();
                layouts.Insert(0, "(None)");
                dropLayouts.DataSource = layouts;
                dropLayouts.DataBind();
                LayoutPanel.Visible = true;
            }

            if (Section != null)
            {
                // Initialize values from SectionInfo
                txtPageHeader.Text = Section.PageHeader;
                txtPageFooter.Text = Section.PageFooter;
                txtFooter.Text = Section.Footer;
                txtPageMetaDesc.Text = Section.PageMetaDescription;
                txtPageMetaKeys.Text = Section.PageMetaKeys;

                // Initialize Log Preview
                if (Section.Logo != String.Empty)
                    imgLogoPreview.ImageUrl = ResolveUrl("~/" + CommunityContext.CalculateGenericHandlersPath(Section.Logo));
                else
                    imgLogoPreview.Visible = false;

                // Initialize transformations
                if (Section.ParentID == -1)
                    pnlTransformations.Visible = false;
                else
                {
                    rdlInheritTransformations.Checked = Section.InheritTransformations;
                    rdlSpecifyTransformations.Checked = !Section.InheritTransformations;
                }

                txtTransformations.Text = Section.Transformations;

                // if not home section, add inherit option
                if (Section.ParentID != -1)
                {
                    dropThemes.Items.Insert(0, new ListItem("Inherit", String.Empty));
                    dropFailTheme.Items.Insert(0, new ListItem("Inherit", String.Empty));
                }

                // select default theme
                dropThemes.SelectedIndex = -1;
                foreach (ListItem item in dropThemes.Items)
                    if (item.Value == Section.Skin)
                        item.Selected = true;

                // select Fail Over theme
                dropFailTheme.SelectedIndex = -1;
                foreach (ListItem item in dropFailTheme.Items)
                    if (item.Value == Section.DefaultSkin)
                        item.Selected = true;

                // select default style
                dropStyles.SelectedIndex = -1;
                foreach (ListItem item in dropStyles.Items)
                    if (item.Value == Section.Style)
                        item.Selected = true;

                // select layout
                dropLayouts.SelectedIndex = -1;
                if (CommunityContext.WebPartsEnabled && (!string.IsNullOrEmpty(Section.Layout)))
                    foreach (ListItem item in dropLayouts.Items)
                        if (item.Value == Section.Layout)
                            item.Selected = true;

                // if not home section, add inherit option
                if (Section.ParentID != -1)
                    dropStyles.Items.Insert(0, new ListItem("Inherit", String.Empty));
            }
            else
            {
                // add inherit option to themes and styles
                dropThemes.Items.Insert(0, new ListItem("Inherit", String.Empty));
                dropStyles.Items.Insert(0, new ListItem("Inherit", String.Empty));

                dropFailTheme.Items.Insert(0, new ListItem("Inherit", String.Empty));

                // hide image logo preview
                imgLogoPreview.Visible = false;
            }

        }
    }

    protected void cvFileName_ServerValidate(object source, System.Web.UI.WebControls.ServerValidateEventArgs args)
    {
        int result = 0;

        String FileName = txtLogo.Value;

        // Remove path
        FileName = FileName.Remove(0, FileName.LastIndexOf("\\") + 1);
        FileName = FileName.Substring(0, FileName.LastIndexOf("."));

        args.IsValid = !int.TryParse(FileName, out result);
    }
}