// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework;
using DotCommunities.Framework.Components;
using DotCommunities.Framework.Managers;

/// <summary>
///	Summary description for SectionGeneral.
/// </summary>
public partial class Admin_Sections_SectionGeneral : System.Web.UI.UserControl
{
    public Section Section;

    public string Name
    {
        get { return txtName.Text; }
    }

    public string Title
    {
        get { return txtTitle.Text; }
    }

    public string MenuTitle
    {
        get { return txtMenuTitle.Text; }
    }

    public string Description
    {
        get { return txtDescription.Text; }
    }

    public bool IsEnabled
    {
        get { return chkIsEnabled.Checked; }
    }

    public string PageTypeName
    {
        get { return radlPageTypes.SelectedItem.Value; }
    }

    public int SectionType
    {
        get { return Int32.Parse(radlPageTypes.SelectedItem.Value); }
    }

    public int ParentSectionID
    {
        get
        {
            if (dropParentSections.SelectedIndex == -1)
                return -1;
            else
                return Int32.Parse(dropParentSections.SelectedItem.Value);
        }
    }

    //*********************************************************************
    //
    // Page_Load Method
    //
    // If we have Section info, then display it -- otherwise,
    // assume adding new section.
    //
    //*********************************************************************
    protected void Page_Load(object sender, System.EventArgs e)
    {
        if (!IsPostBack)
        {
            if (Section != null)
            {
                // Initialize values from Section object
                txtName.Text = Section.Name;
                txtTitle.Text = Section.Title;
                txtMenuTitle.Text = Section.MenuTitle;
                txtDescription.Text = Section.Description;
                chkIsEnabled.Checked = Section.IsEnabled;
                pnlType.Visible = false;

                if (Section.ParentID == -1 || Section.IsRoot || Section.IsSystem)
                {
                    pnlParentSection.Visible = false;
                    // You should not be able to disable the homepage or system 
                    // sections - If setting site to be disabled, this should be done
                    // with the site online/offline control in the administration menu
                    pnlEnabled.Visible = false;
                }
                else
                {
                    dropParentSections.DataSource = FrameworkManager.GetPossibleParents(Section.SectionID);
                    dropParentSections.DataTextField = "Section_Name";
                    dropParentSections.DataValueField = "Section_ID";
                    dropParentSections.DataBind();
                }

                // Assign default value (notice we loop since Parent might not exist)
                string strParentID = Section.ParentID.ToString();
                foreach (ListItem item in dropParentSections.Items)
                    if (item.Value == strParentID)
                        item.Selected = true;

            }
            else
            {
                pnlType.Visible = true;
                radlPageTypes.DataSource = ContentTypesManager.GetModuleSections(true).Values;
                radlPageTypes.DataTextField = "TitleAndDescription";
                radlPageTypes.DataValueField = "Name";
                radlPageTypes.DataBind();

                dropParentSections.DataSource = FrameworkManager.GetPossibleParents(-1);
                dropParentSections.DataTextField = "Section_Name";
                dropParentSections.DataValueField = "Section_ID";
                dropParentSections.DataBind();

                // Set Default values
                radlPageTypes.Items[0].Selected = true;
                chkIsEnabled.Checked = true;
            }
        }
    }
}
