// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework;
using DotCommunities.Framework.Enums;
using DotCommunities.Framework.Controls;
using DotCommunities.Framework.Managers;
using DotCommunities.Framework.Components;

public partial class Admin_SiteMessages_Default : AdministrationPage
{
    protected override string PageTitle
    {
        get { return "Manage Messages"; }
    }

    protected override string PageSubTitle
    {
        get { return "Edit the event messages for the site."; }
    }

    protected override string[] MenuItems
    {
        get { return new string[] { "Home", "Configuration" }; }
    }

    protected override string[] MenuLinks
    {
        get { return new string[] { "Main/Default.aspx", "Main/Configuration.aspx" }; }
    }

    protected override string[] ActionItems
    {
        get { return new string[] { }; }
    }

    protected override string[] ActionLinks
    {
        get { return new string[] { }; }
    }

    //*******************************************************
    //
    // Bind all message titles to dropdownlist
    // and body of the first message to TextBox
    // when the page first loads.
    //
    //*******************************************************

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            dropMessageNames.DataSource = FrameworkManager.GetMessages().Values;
            dropMessageNames.DataTextField = "Name";
            dropMessageNames.DataValueField = "MessageID";
            dropMessageNames.DataBind();

            BindMessage();
        }
    }

    //*******************************************************
    //
    // Display message body when user selects a new
    // message to view.
    //
    //*******************************************************

    protected void MessageChanged(object sender, EventArgs e)
    {
        BindMessage();
    }

    //*******************************************************
    //
    // Display body of the current message in the TextBox.
    //
    //*******************************************************

    void BindMessage()
    {
        Message msg = FrameworkManager.GetMessage(int.Parse(dropMessageNames.SelectedItem.Value));
        if (msg != null)
        {
            lblMessageDescription.Text = msg.Description;
            txtMessageTitle.Text = msg.Subject;
            txtMessageBody.Text = msg.Body;
        }
    }

    //*******************************************************
    //
    // Save changes to the message.
    //
    //*******************************************************

    protected void btnEdit_Click(object sender, EventArgs e)
    {
        try
        {
            FrameworkManager.EditMessage(int.Parse(dropMessageNames.SelectedItem.Value), null, txtMessageTitle.Text, CommunityContext.ConvertRelativeUrlsToAbsoluteUrls(txtMessageBody.Text));
            // Let the user know the message has changed
            ShowInformation("Message updated sucessfully");
        }
        catch (Exception ex)
        {
            // Let the user know there was an error
            ShowError("Could not update message text");
            // Log the error
            LogManager.LogException(EventCode.Database, LogManager.LogCategory.Exceptions, ex);
        }
    }
}
