// =========================================================================
// .communities - The Free Community Content Management Framework
// Copyright  2007 by Ed Quinn (http://edquinn.net)
// =========================================================================
//
// For more information about this software, visit:
// http://www.DotCommunities.org (official site)
// http://www.codeplex.com/DotCommunities (source code)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Shared Source License displayed here:
// http://www.codeplex.com/DotCommunities/Project/License.aspx
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// Shared Source License for more details.
//
// Please do not remove any copyright or other notices from this Software.
//
// =========================================================================

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Drawing;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotCommunities.Framework;
using DotCommunities.Framework.Components;
using DotCommunities.Framework.Controls;

public partial class Admin_Users_EditUser : AdministrationPage
{
    private MembershipUser user;

    protected override string PageTitle
    {
        get { return "Edit User"; }
    }

    protected override string PageSubTitle
    {
        get { return "Use this page to edit a .communities registered user."; }
    }

    protected override string[] MenuItems
    {
        get { return new string[] { "Home", "User List" }; }
    }

    protected override string[] MenuLinks
    {
        get { return new string[] { "Main/Default.aspx", "Users/Default.aspx" }; }
    }

    protected override string[] ActionItems
    {
        get { return new string[] { }; }
    }

    protected override string[] ActionLinks
    {
        get { return new string[] { }; }
    }

    protected string EditUserName
    {
        get { return Request.QueryString["id"]; }
    }

    protected void Page_Init(object sender, EventArgs e)
    {
        // Redirect the user if there is no user name
        if (string.IsNullOrEmpty(EditUserName))
            ReturnInvalidUserNameMessage();
    }

    private void ReturnInvalidUserNameMessage()
    {
        string msg = HttpUtility.UrlEncode("You must select a valid user name from the list.");
        Response.Redirect("Default.aspx?Message=Warning&MessageText=" + msg);
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        user = Membership.GetUser(EditUserName, false);
        if (user == null)
            ReturnInvalidUserNameMessage();

        if (!Page.IsPostBack)
        {
            txtEmailAddress.Text = user.Email;

            lblRegistered.Text = user.CreationDate.ToString();
            lblLastLogin.Text = user.LastLoginDate.ToString();
            lblLastActivity.Text = user.LastActivityDate.ToString();

            lblOnlineNow.Text = user.IsOnline ? "Yes" : "No";
            lblOnlineNow.ForeColor = user.IsOnline ? Color.Green : Color.Red;

            chkUserApproved.Checked = user.IsApproved;
            chkUserLockedOut.Checked = user.IsLockedOut;

            // You cannot lock out a user, only clear the status
            if (!user.IsLockedOut)
                chkUserLockedOut.Enabled = false;

            MembershipUser currentUser = Membership.GetUser();

            // You cannot disable yourself
            if ((currentUser != null && (currentUser.UserName.ToLowerInvariant() == user.UserName.ToLowerInvariant())) || (!Roles.IsUserInRole("System")))
                chkUserApproved.Enabled = false;

            ltpUserRoles.DataSource = CommunityUser.CommunityRoles;
            ltpUserRoles.SelectedItems = CommunityUser.GetUserRoles(user.UserName);
            ltpUserRoles.DataBind();
        }
    }

    protected void btnEdit_Click(object sender, EventArgs e)
    {
        if (Page.IsValid)
        {
            try
            {
                // Update the user status
                if (user.IsApproved != chkUserApproved.Checked)
                {
                    user.IsApproved = chkUserApproved.Checked;
                    Membership.UpdateUser(user);
                }
                // Update the locked out status
                if (user.IsLockedOut && (!chkUserLockedOut.Checked))
                    user.UnlockUser();
                // Update the e-mail address
                CommunityUser.UpdateEMailAddress(user.UserName, txtEmailAddress.Text);
                // Remove all the roles first
                Roles.RemoveUserFromRoles(user.UserName, Roles.GetRolesForUser(user.UserName));
                // Update the user roles
                Roles.AddUserToRoles(user.UserName, ltpUserRoles.SelectedItems);                        
            }
            catch (Exception ex)
            {
                ShowError("Could not update the user.");
                throw ex;
            }

            // Redirect back to user list page
            string msg = HttpUtility.UrlEncode("User updated successfully.");
            Response.Redirect("Default.aspx?Message=Information&MessageText=" + msg);
        }
    }
}
